Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.access_requests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


16835
16836
16837
16838
16839
16840
16841
16842
16843
16844
16845
16846
16847
16848
16849
16850
16851
16852
16853
16854
16855
16856
16857
16858
16859
16860
16861
16862
16863
16864
16865
16866
16867
16868
16869
16870
16871
16872
16873
16874
16875
16876
16877
16878
16879
16880
16881
16882
16883
16884
16885
16886
16887
16888
16889
16890
16891
16892
16893
16894
16895
16896
16897
16898
16899
16900
16901
16902
16903
16904
16905
16906
16907
16908
16909
16910
16911
16912
16913
16914
16915
16916
16917
16918
16919
16920
16921
16922
16923
16924
16925
16926
16927
16928
16929
16930
16931
16932
16933
16934
# File 'lib/infrawrench/client.rb', line 16835

def initialize(**options)
  @transport = Transport.new(**options)
  @access_requests = AccessRequestsNamespace.new(@transport)
  @access_review = AccessReviewNamespace.new(@transport)
  @accounts = AccountsNamespace.new(@transport)
  @agent = AgentNamespace.new(@transport)
  @agent_registrations = AgentRegistrationsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @alert_rules = AlertRulesNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @apps = AppsNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @backups = BackupsNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @billing_rules = BillingRulesNamespace.new(@transport)
  @blast_radius = BlastRadiusNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @business_metrics = BusinessMetricsNamespace.new(@transport)
  @calendar = CalendarNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @chat = ChatNamespace.new(@transport)
  @commitments = CommitmentsNamespace.new(@transport)
  @config = ConfigNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @cost_alerts = CostAlertsNamespace.new(@transport)
  @cost_annotations = CostAnnotationsNamespace.new(@transport)
  @cost_centres = CostCentresNamespace.new(@transport)
  @cost_exports = CostExportsNamespace.new(@transport)
  @cost_report_folders = CostReportFoldersNamespace.new(@transport)
  @cost_report_notifications = CostReportNotificationsNamespace.new(@transport)
  @cost_reports = CostReportsNamespace.new(@transport)
  @cost_scenarios = CostScenariosNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @credential_hygiene = CredentialHygieneNamespace.new(@transport)
  @credits = CreditsNamespace.new(@transport)
  @currency = CurrencyNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @dependency_graph = DependencyGraphNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @dns = DnsNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @environment_diff = EnvironmentDiffNamespace.new(@transport)
  @environments = EnvironmentsNamespace.new(@transport)
  @expiring = ExpiringNamespace.new(@transport)
  @iac = IacNamespace.new(@transport)
  @incidents = IncidentsNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @invoices = InvoicesNamespace.new(@transport)
  @jira = JiraNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @leases = LeasesNamespace.new(@transport)
  @linear = LinearNamespace.new(@transport)
  @log_workspaces = LogWorkspacesNamespace.new(@transport)
  @managed_accounts = ManagedAccountsNamespace.new(@transport)
  @metric_alerts = MetricAlertsNamespace.new(@transport)
  @moment = MomentNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @network_flows = NetworkFlowsNamespace.new(@transport)
  @on_call = OnCallNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @ownership = OwnershipNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @posture = PostureNamespace.new(@transport)
  @probes = ProbesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @query_monitors = QueryMonitorsNamespace.new(@transport)
  @quotas = QuotasNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @rightsizing = RightsizingNamespace.new(@transport)
  @runbooks = RunbooksNamespace.new(@transport)
  @saved_cost_filters = SavedCostFiltersNamespace.new(@transport)
  @schedules = SchedulesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @session_recordings = SessionRecordingsNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @shared_consoles = SharedConsolesNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_fanout = SshFanoutNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @status = StatusNamespace.new(@transport)
  @status_incidents = StatusIncidentsNamespace.new(@transport)
  @status_pages = StatusPagesNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @tag_policy = TagPolicyNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @wallboard = WallboardNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
  @workflow_secrets = WorkflowSecretsNamespace.new(@transport)
  @workflows = WorkflowsNamespace.new(@transport)
end

Instance Attribute Details

#access_requestsAccessRequestsNamespace (readonly)

Returns client.access_requests.

Returns:



16638
16639
16640
# File 'lib/infrawrench/client.rb', line 16638

def access_requests
  @access_requests
end

#access_reviewAccessReviewNamespace (readonly)

Returns client.access_review.

Returns:



16640
16641
16642
# File 'lib/infrawrench/client.rb', line 16640

def access_review
  @access_review
end

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



16642
16643
16644
# File 'lib/infrawrench/client.rb', line 16642

def accounts
  @accounts
end

#agentAgentNamespace (readonly)

Returns client.agent.

Returns:



16644
16645
16646
# File 'lib/infrawrench/client.rb', line 16644

def agent
  @agent
end

#agent_registrationsAgentRegistrationsNamespace (readonly)

Returns client.agent_registrations.

Returns:



16646
16647
16648
# File 'lib/infrawrench/client.rb', line 16646

def agent_registrations
  @agent_registrations
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



16648
16649
16650
# File 'lib/infrawrench/client.rb', line 16648

def agents
  @agents
end

#alert_rulesAlertRulesNamespace (readonly)

Returns client.alert_rules.

Returns:



16650
16651
16652
# File 'lib/infrawrench/client.rb', line 16650

def alert_rules
  @alert_rules
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



16652
16653
16654
# File 'lib/infrawrench/client.rb', line 16652

def api_keys
  @api_keys
end

#appsAppsNamespace (readonly)

Returns client.apps.

Returns:



16654
16655
16656
# File 'lib/infrawrench/client.rb', line 16654

def apps
  @apps
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



16656
16657
16658
# File 'lib/infrawrench/client.rb', line 16656

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



16658
16659
16660
# File 'lib/infrawrench/client.rb', line 16658

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



16660
16661
16662
# File 'lib/infrawrench/client.rb', line 16660

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



16662
16663
16664
# File 'lib/infrawrench/client.rb', line 16662

def auth
  @auth
end

#backupsBackupsNamespace (readonly)

Returns client.backups.

Returns:



16664
16665
16666
# File 'lib/infrawrench/client.rb', line 16664

def backups
  @backups
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



16666
16667
16668
# File 'lib/infrawrench/client.rb', line 16666

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



16668
16669
16670
# File 'lib/infrawrench/client.rb', line 16668

def billing
  @billing
end

#billing_rulesBillingRulesNamespace (readonly)

Returns client.billing_rules.

Returns:



16670
16671
16672
# File 'lib/infrawrench/client.rb', line 16670

def billing_rules
  @billing_rules
end

#blast_radiusBlastRadiusNamespace (readonly)

Returns client.blast_radius.

Returns:



16672
16673
16674
# File 'lib/infrawrench/client.rb', line 16672

def blast_radius
  @blast_radius
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



16674
16675
16676
# File 'lib/infrawrench/client.rb', line 16674

def budgets
  @budgets
end

#business_metricsBusinessMetricsNamespace (readonly)

Returns client.business_metrics.

Returns:



16676
16677
16678
# File 'lib/infrawrench/client.rb', line 16676

def business_metrics
  @business_metrics
end

#calendarCalendarNamespace (readonly)

Returns client.calendar.

Returns:



16678
16679
16680
# File 'lib/infrawrench/client.rb', line 16678

def calendar
  @calendar
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



16680
16681
16682
# File 'lib/infrawrench/client.rb', line 16680

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



16682
16683
16684
# File 'lib/infrawrench/client.rb', line 16682

def changes
  @changes
end

#chatChatNamespace (readonly)

Returns client.chat.

Returns:



16684
16685
16686
# File 'lib/infrawrench/client.rb', line 16684

def chat
  @chat
end

#commitmentsCommitmentsNamespace (readonly)

Returns client.commitments.

Returns:



16686
16687
16688
# File 'lib/infrawrench/client.rb', line 16686

def commitments
  @commitments
end

#configConfigNamespace (readonly)

Returns client.config.

Returns:



16688
16689
16690
# File 'lib/infrawrench/client.rb', line 16688

def config
  @config
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



16690
16691
16692
# File 'lib/infrawrench/client.rb', line 16690

def connect
  @connect
end

#cost_alertsCostAlertsNamespace (readonly)

Returns client.cost_alerts.

Returns:



16692
16693
16694
# File 'lib/infrawrench/client.rb', line 16692

def cost_alerts
  @cost_alerts
end

#cost_annotationsCostAnnotationsNamespace (readonly)

Returns client.cost_annotations.

Returns:



16694
16695
16696
# File 'lib/infrawrench/client.rb', line 16694

def cost_annotations
  @cost_annotations
end

#cost_centresCostCentresNamespace (readonly)

Returns client.cost_centres.

Returns:



16696
16697
16698
# File 'lib/infrawrench/client.rb', line 16696

def cost_centres
  @cost_centres
end

#cost_exportsCostExportsNamespace (readonly)

Returns client.cost_exports.

Returns:



16698
16699
16700
# File 'lib/infrawrench/client.rb', line 16698

def cost_exports
  @cost_exports
end

#cost_report_foldersCostReportFoldersNamespace (readonly)

Returns client.cost_report_folders.

Returns:



16700
16701
16702
# File 'lib/infrawrench/client.rb', line 16700

def cost_report_folders
  @cost_report_folders
end

#cost_report_notificationsCostReportNotificationsNamespace (readonly)

Returns client.cost_report_notifications.

Returns:



16702
16703
16704
# File 'lib/infrawrench/client.rb', line 16702

def cost_report_notifications
  @cost_report_notifications
end

#cost_reportsCostReportsNamespace (readonly)

Returns client.cost_reports.

Returns:



16704
16705
16706
# File 'lib/infrawrench/client.rb', line 16704

def cost_reports
  @cost_reports
end

#cost_scenariosCostScenariosNamespace (readonly)

Returns client.cost_scenarios.

Returns:



16706
16707
16708
# File 'lib/infrawrench/client.rb', line 16706

def cost_scenarios
  @cost_scenarios
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



16708
16709
16710
# File 'lib/infrawrench/client.rb', line 16708

def costs
  @costs
end

#credential_hygieneCredentialHygieneNamespace (readonly)

Returns client.credential_hygiene.

Returns:



16710
16711
16712
# File 'lib/infrawrench/client.rb', line 16710

def credential_hygiene
  @credential_hygiene
end

#creditsCreditsNamespace (readonly)

Returns client.credits.

Returns:



16712
16713
16714
# File 'lib/infrawrench/client.rb', line 16712

def credits
  @credits
end

#currencyCurrencyNamespace (readonly)

Returns client.currency.

Returns:



16714
16715
16716
# File 'lib/infrawrench/client.rb', line 16714

def currency
  @currency
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



16716
16717
16718
# File 'lib/infrawrench/client.rb', line 16716

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



16718
16719
16720
# File 'lib/infrawrench/client.rb', line 16718

def dashboards
  @dashboards
end

#dependency_graphDependencyGraphNamespace (readonly)

Returns client.dependency_graph.

Returns:



16720
16721
16722
# File 'lib/infrawrench/client.rb', line 16720

def dependency_graph
  @dependency_graph
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



16722
16723
16724
# File 'lib/infrawrench/client.rb', line 16722

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



16724
16725
16726
# File 'lib/infrawrench/client.rb', line 16724

def digest
  @digest
end

#dnsDnsNamespace (readonly)

Returns client.dns.

Returns:



16726
16727
16728
# File 'lib/infrawrench/client.rb', line 16726

def dns
  @dns
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



16728
16729
16730
# File 'lib/infrawrench/client.rb', line 16728

def docker
  @docker
end

#environment_diffEnvironmentDiffNamespace (readonly)

Returns client.environment_diff.

Returns:



16730
16731
16732
# File 'lib/infrawrench/client.rb', line 16730

def environment_diff
  @environment_diff
end

#environmentsEnvironmentsNamespace (readonly)

Returns client.environments.

Returns:



16732
16733
16734
# File 'lib/infrawrench/client.rb', line 16732

def environments
  @environments
end

#expiringExpiringNamespace (readonly)

Returns client.expiring.

Returns:



16734
16735
16736
# File 'lib/infrawrench/client.rb', line 16734

def expiring
  @expiring
end

#iacIacNamespace (readonly)

Returns client.iac.

Returns:



16736
16737
16738
# File 'lib/infrawrench/client.rb', line 16736

def iac
  @iac
end

#incidentsIncidentsNamespace (readonly)

Returns client.incidents.

Returns:



16738
16739
16740
# File 'lib/infrawrench/client.rb', line 16738

def incidents
  @incidents
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



16740
16741
16742
# File 'lib/infrawrench/client.rb', line 16740

def invitations
  @invitations
end

#invoicesInvoicesNamespace (readonly)

Returns client.invoices.

Returns:



16742
16743
16744
# File 'lib/infrawrench/client.rb', line 16742

def invoices
  @invoices
end

#jiraJiraNamespace (readonly)

Returns client.jira.

Returns:



16744
16745
16746
# File 'lib/infrawrench/client.rb', line 16744

def jira
  @jira
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



16746
16747
16748
# File 'lib/infrawrench/client.rb', line 16746

def kv
  @kv
end

#leasesLeasesNamespace (readonly)

Returns client.leases.

Returns:



16748
16749
16750
# File 'lib/infrawrench/client.rb', line 16748

def leases
  @leases
end

#linearLinearNamespace (readonly)

Returns client.linear.

Returns:



16750
16751
16752
# File 'lib/infrawrench/client.rb', line 16750

def linear
  @linear
end

#log_workspacesLogWorkspacesNamespace (readonly)

Returns client.log_workspaces.

Returns:



16752
16753
16754
# File 'lib/infrawrench/client.rb', line 16752

def log_workspaces
  @log_workspaces
end

#managed_accountsManagedAccountsNamespace (readonly)

Returns client.managed_accounts.

Returns:



16754
16755
16756
# File 'lib/infrawrench/client.rb', line 16754

def managed_accounts
  @managed_accounts
end

#metric_alertsMetricAlertsNamespace (readonly)

Returns client.metric_alerts.

Returns:



16756
16757
16758
# File 'lib/infrawrench/client.rb', line 16756

def metric_alerts
  @metric_alerts
end

#momentMomentNamespace (readonly)

Returns client.moment.

Returns:



16758
16759
16760
# File 'lib/infrawrench/client.rb', line 16758

def moment
  @moment
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



16760
16761
16762
# File 'lib/infrawrench/client.rb', line 16760

def msteams
  @msteams
end

#network_flowsNetworkFlowsNamespace (readonly)

Returns client.network_flows.

Returns:



16762
16763
16764
# File 'lib/infrawrench/client.rb', line 16762

def network_flows
  @network_flows
end

#on_callOnCallNamespace (readonly)

Returns client.on_call.

Returns:



16764
16765
16766
# File 'lib/infrawrench/client.rb', line 16764

def on_call
  @on_call
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



16766
16767
16768
# File 'lib/infrawrench/client.rb', line 16766

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



16768
16769
16770
# File 'lib/infrawrench/client.rb', line 16768

def orphans
  @orphans
end

#ownershipOwnershipNamespace (readonly)

Returns client.ownership.

Returns:



16770
16771
16772
# File 'lib/infrawrench/client.rb', line 16770

def ownership
  @ownership
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



16772
16773
16774
# File 'lib/infrawrench/client.rb', line 16772

def pages
  @pages
end

#posturePostureNamespace (readonly)

Returns client.posture.

Returns:



16774
16775
16776
# File 'lib/infrawrench/client.rb', line 16774

def posture
  @posture
end

#probesProbesNamespace (readonly)

Returns client.probes.

Returns:



16776
16777
16778
# File 'lib/infrawrench/client.rb', line 16776

def probes
  @probes
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



16778
16779
16780
# File 'lib/infrawrench/client.rb', line 16778

def profile
  @profile
end

#query_monitorsQueryMonitorsNamespace (readonly)

Returns client.query_monitors.

Returns:



16780
16781
16782
# File 'lib/infrawrench/client.rb', line 16780

def query_monitors
  @query_monitors
end

#quotasQuotasNamespace (readonly)

Returns client.quotas.

Returns:



16782
16783
16784
# File 'lib/infrawrench/client.rb', line 16782

def quotas
  @quotas
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



16784
16785
16786
# File 'lib/infrawrench/client.rb', line 16784

def resources
  @resources
end

#rightsizingRightsizingNamespace (readonly)

Returns client.rightsizing.

Returns:



16786
16787
16788
# File 'lib/infrawrench/client.rb', line 16786

def rightsizing
  @rightsizing
end

#runbooksRunbooksNamespace (readonly)

Returns client.runbooks.

Returns:



16788
16789
16790
# File 'lib/infrawrench/client.rb', line 16788

def runbooks
  @runbooks
end

#saved_cost_filtersSavedCostFiltersNamespace (readonly)

Returns client.saved_cost_filters.

Returns:



16790
16791
16792
# File 'lib/infrawrench/client.rb', line 16790

def saved_cost_filters
  @saved_cost_filters
end

#schedulesSchedulesNamespace (readonly)

Returns client.schedules.

Returns:



16792
16793
16794
# File 'lib/infrawrench/client.rb', line 16792

def schedules
  @schedules
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



16794
16795
16796
# File 'lib/infrawrench/client.rb', line 16794

def search
  @search
end

#session_recordingsSessionRecordingsNamespace (readonly)

Returns client.session_recordings.

Returns:



16796
16797
16798
# File 'lib/infrawrench/client.rb', line 16796

def session_recordings
  @session_recordings
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



16798
16799
16800
# File 'lib/infrawrench/client.rb', line 16798

def sftp
  @sftp
end

#shared_consolesSharedConsolesNamespace (readonly)

Returns client.shared_consoles.

Returns:



16800
16801
16802
# File 'lib/infrawrench/client.rb', line 16800

def shared_consoles
  @shared_consoles
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



16802
16803
16804
# File 'lib/infrawrench/client.rb', line 16802

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



16804
16805
16806
# File 'lib/infrawrench/client.rb', line 16804

def sql
  @sql
end

#ssh_fanoutSshFanoutNamespace (readonly)

Returns client.ssh_fanout.

Returns:



16806
16807
16808
# File 'lib/infrawrench/client.rb', line 16806

def ssh_fanout
  @ssh_fanout
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



16808
16809
16810
# File 'lib/infrawrench/client.rb', line 16808

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



16810
16811
16812
# File 'lib/infrawrench/client.rb', line 16810

def ssh_tunnels
  @ssh_tunnels
end

#statusStatusNamespace (readonly)

Returns client.status.

Returns:



16812
16813
16814
# File 'lib/infrawrench/client.rb', line 16812

def status
  @status
end

#status_incidentsStatusIncidentsNamespace (readonly)

Returns client.status_incidents.

Returns:



16814
16815
16816
# File 'lib/infrawrench/client.rb', line 16814

def status_incidents
  @status_incidents
end

#status_pagesStatusPagesNamespace (readonly)

Returns client.status_pages.

Returns:



16816
16817
16818
# File 'lib/infrawrench/client.rb', line 16816

def status_pages
  @status_pages
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



16818
16819
16820
# File 'lib/infrawrench/client.rb', line 16818

def storage
  @storage
end

#tag_policyTagPolicyNamespace (readonly)

Returns client.tag_policy.

Returns:



16820
16821
16822
# File 'lib/infrawrench/client.rb', line 16820

def tag_policy
  @tag_policy
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



16822
16823
16824
# File 'lib/infrawrench/client.rb', line 16822

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



16636
16637
16638
# File 'lib/infrawrench/client.rb', line 16636

def transport
  @transport
end

#wallboardWallboardNamespace (readonly)

Returns client.wallboard.

Returns:



16824
16825
16826
# File 'lib/infrawrench/client.rb', line 16824

def wallboard
  @wallboard
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



16826
16827
16828
# File 'lib/infrawrench/client.rb', line 16826

def workflow_approvals
  @workflow_approvals
end

#workflow_secretsWorkflowSecretsNamespace (readonly)

Returns client.workflow_secrets.

Returns:



16828
16829
16830
# File 'lib/infrawrench/client.rb', line 16828

def workflow_secrets
  @workflow_secrets
end

#workflowsWorkflowsNamespace (readonly)

Returns client.workflows.

Returns:



16830
16831
16832
# File 'lib/infrawrench/client.rb', line 16830

def workflows
  @workflows
end