Class: Infrawrench::ConnectNamespace

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

client.connect

Instance Method Summary collapse

Constructor Details

#initialize(transport) ⇒ ConnectNamespace

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of ConnectNamespace.

Parameters:



3910
3911
3912
# File 'lib/infrawrench/client.rb', line 3910

def initialize(transport)
  @transport = transport
end

Instance Method Details

#env_deploy(body:, org_id: nil, request_options: nil) ⇒ Hash

Deploy env vars from a source resource to an SSH target

Requires permission: resources:execute.

POST /api/org/orgId/connect/env-deploy

Raises on 400: Bad request

Raises on 404: Not found

Parameters:

  • org_id (String, nil) (defaults to: nil)

    Organization id. Defaults to the org_id the client was constructed with.

  • body (Hash)

    Request body, shaped as ConnectEnvDeployRequest.

  • request_options (Hash, nil) (defaults to: nil)

    Per-call :headers, :timeout and :open_timeout.

  • body: (connect_env_deploy_request)
  • org_id: (String, nil) (defaults to: nil)
  • request_options: (Hash[Symbol, untyped], nil) (defaults to: nil)

Returns:

  • (Hash)

    Parsed JSON, shaped as Ok — see sig/infrawrench/sdk.rbs.

Raises:



3930
3931
3932
3933
3934
3935
3936
3937
3938
# File 'lib/infrawrench/client.rb', line 3930

def env_deploy(body:, org_id: nil, request_options: nil)
  @transport.request(
    http_method: "POST",
    path: "/api/org/{orgId}/connect/env-deploy",
    path_params: { "orgId" => org_id },
    body: body,
    request_options: request_options
  )
end

#secret_export(body:, org_id: nil, request_options: nil) ⇒ Hash

Materialize source outputs as a secret in the target (e.g. K8s)

Requires permission: resources:write.

POST /api/org/orgId/connect/secret-export

Raises on 400: Bad request

Raises on 404: Not found

Parameters:

  • org_id (String, nil) (defaults to: nil)

    Organization id. Defaults to the org_id the client was constructed with.

  • body (Hash)

    Request body, shaped as ConnectSecretExportRequest.

  • request_options (Hash, nil) (defaults to: nil)

    Per-call :headers, :timeout and :open_timeout.

  • body: (connect_secret_export_request)
  • org_id: (String, nil) (defaults to: nil)
  • request_options: (Hash[Symbol, untyped], nil) (defaults to: nil)

Returns:

  • (Hash)

    Parsed JSON, shaped as Ok — see sig/infrawrench/sdk.rbs.

Raises:



3956
3957
3958
3959
3960
3961
3962
3963
3964
# File 'lib/infrawrench/client.rb', line 3956

def secret_export(body:, org_id: nil, request_options: nil)
  @transport.request(
    http_method: "POST",
    path: "/api/org/{orgId}/connect/secret-export",
    path_params: { "orgId" => org_id },
    body: body,
    request_options: request_options
  )
end

#templates(body:, org_id: nil, request_options: nil) ⇒ Hash

List secret-export templates and target capabilities

Requires permission: resources:read.

POST /api/org/orgId/connect/templates

Raises on 404: Not found

Parameters:

  • org_id (String, nil) (defaults to: nil)

    Organization id. Defaults to the org_id the client was constructed with.

  • body (Hash)

    Request body, shaped as ConnectTemplatesRequest.

  • request_options (Hash, nil) (defaults to: nil)

    Per-call :headers, :timeout and :open_timeout.

  • body: (connect_templates_request)
  • org_id: (String, nil) (defaults to: nil)
  • request_options: (Hash[Symbol, untyped], nil) (defaults to: nil)

Returns:

  • (Hash)

    Parsed JSON, shaped as ConnectTemplatesResponse — see sig/infrawrench/sdk.rbs.

Raises:



3981
3982
3983
3984
3985
3986
3987
3988
3989
# File 'lib/infrawrench/client.rb', line 3981

def templates(body:, org_id: nil, request_options: nil)
  @transport.request(
    http_method: "POST",
    path: "/api/org/{orgId}/connect/templates",
    path_params: { "orgId" => org_id },
    body: body,
    request_options: request_options
  )
end