Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.access_requests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


15906
15907
15908
15909
15910
15911
15912
15913
15914
15915
15916
15917
15918
15919
15920
15921
15922
15923
15924
15925
15926
15927
15928
15929
15930
15931
15932
15933
15934
15935
15936
15937
15938
15939
15940
15941
15942
15943
15944
15945
15946
15947
15948
15949
15950
15951
15952
15953
15954
15955
15956
15957
15958
15959
15960
15961
15962
15963
15964
15965
15966
15967
15968
15969
15970
15971
15972
15973
15974
15975
15976
15977
15978
15979
15980
15981
15982
15983
15984
15985
15986
15987
15988
15989
15990
15991
15992
15993
15994
15995
15996
15997
15998
15999
16000
16001
16002
# File 'lib/infrawrench/client.rb', line 15906

def initialize(**options)
  @transport = Transport.new(**options)
  @access_requests = AccessRequestsNamespace.new(@transport)
  @access_review = AccessReviewNamespace.new(@transport)
  @accounts = AccountsNamespace.new(@transport)
  @agent = AgentNamespace.new(@transport)
  @agent_registrations = AgentRegistrationsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @alert_rules = AlertRulesNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @apps = AppsNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @backups = BackupsNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @billing_rules = BillingRulesNamespace.new(@transport)
  @blast_radius = BlastRadiusNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @business_metrics = BusinessMetricsNamespace.new(@transport)
  @calendar = CalendarNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @chat = ChatNamespace.new(@transport)
  @commitments = CommitmentsNamespace.new(@transport)
  @config = ConfigNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @cost_alerts = CostAlertsNamespace.new(@transport)
  @cost_annotations = CostAnnotationsNamespace.new(@transport)
  @cost_centres = CostCentresNamespace.new(@transport)
  @cost_exports = CostExportsNamespace.new(@transport)
  @cost_report_folders = CostReportFoldersNamespace.new(@transport)
  @cost_report_notifications = CostReportNotificationsNamespace.new(@transport)
  @cost_reports = CostReportsNamespace.new(@transport)
  @cost_scenarios = CostScenariosNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @credential_hygiene = CredentialHygieneNamespace.new(@transport)
  @credits = CreditsNamespace.new(@transport)
  @currency = CurrencyNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @dependency_graph = DependencyGraphNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @dns = DnsNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @environment_diff = EnvironmentDiffNamespace.new(@transport)
  @environments = EnvironmentsNamespace.new(@transport)
  @expiring = ExpiringNamespace.new(@transport)
  @iac = IacNamespace.new(@transport)
  @incidents = IncidentsNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @invoices = InvoicesNamespace.new(@transport)
  @jira = JiraNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @leases = LeasesNamespace.new(@transport)
  @linear = LinearNamespace.new(@transport)
  @log_workspaces = LogWorkspacesNamespace.new(@transport)
  @managed_accounts = ManagedAccountsNamespace.new(@transport)
  @metric_alerts = MetricAlertsNamespace.new(@transport)
  @moment = MomentNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @network_flows = NetworkFlowsNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @ownership = OwnershipNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @posture = PostureNamespace.new(@transport)
  @probes = ProbesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @quotas = QuotasNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @rightsizing = RightsizingNamespace.new(@transport)
  @saved_cost_filters = SavedCostFiltersNamespace.new(@transport)
  @schedules = SchedulesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @session_recordings = SessionRecordingsNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @shared_consoles = SharedConsolesNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_fanout = SshFanoutNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @status = StatusNamespace.new(@transport)
  @status_incidents = StatusIncidentsNamespace.new(@transport)
  @status_pages = StatusPagesNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @tag_policy = TagPolicyNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @wallboard = WallboardNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
  @workflow_secrets = WorkflowSecretsNamespace.new(@transport)
  @workflows = WorkflowsNamespace.new(@transport)
end

Instance Attribute Details

#access_requestsAccessRequestsNamespace (readonly)

Returns client.access_requests.

Returns:



15715
15716
15717
# File 'lib/infrawrench/client.rb', line 15715

def access_requests
  @access_requests
end

#access_reviewAccessReviewNamespace (readonly)

Returns client.access_review.

Returns:



15717
15718
15719
# File 'lib/infrawrench/client.rb', line 15717

def access_review
  @access_review
end

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



15719
15720
15721
# File 'lib/infrawrench/client.rb', line 15719

def accounts
  @accounts
end

#agentAgentNamespace (readonly)

Returns client.agent.

Returns:



15721
15722
15723
# File 'lib/infrawrench/client.rb', line 15721

def agent
  @agent
end

#agent_registrationsAgentRegistrationsNamespace (readonly)

Returns client.agent_registrations.

Returns:



15723
15724
15725
# File 'lib/infrawrench/client.rb', line 15723

def agent_registrations
  @agent_registrations
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



15725
15726
15727
# File 'lib/infrawrench/client.rb', line 15725

def agents
  @agents
end

#alert_rulesAlertRulesNamespace (readonly)

Returns client.alert_rules.

Returns:



15727
15728
15729
# File 'lib/infrawrench/client.rb', line 15727

def alert_rules
  @alert_rules
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



15729
15730
15731
# File 'lib/infrawrench/client.rb', line 15729

def api_keys
  @api_keys
end

#appsAppsNamespace (readonly)

Returns client.apps.

Returns:



15731
15732
15733
# File 'lib/infrawrench/client.rb', line 15731

def apps
  @apps
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



15733
15734
15735
# File 'lib/infrawrench/client.rb', line 15733

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



15735
15736
15737
# File 'lib/infrawrench/client.rb', line 15735

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



15737
15738
15739
# File 'lib/infrawrench/client.rb', line 15737

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



15739
15740
15741
# File 'lib/infrawrench/client.rb', line 15739

def auth
  @auth
end

#backupsBackupsNamespace (readonly)

Returns client.backups.

Returns:



15741
15742
15743
# File 'lib/infrawrench/client.rb', line 15741

def backups
  @backups
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



15743
15744
15745
# File 'lib/infrawrench/client.rb', line 15743

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



15745
15746
15747
# File 'lib/infrawrench/client.rb', line 15745

def billing
  @billing
end

#billing_rulesBillingRulesNamespace (readonly)

Returns client.billing_rules.

Returns:



15747
15748
15749
# File 'lib/infrawrench/client.rb', line 15747

def billing_rules
  @billing_rules
end

#blast_radiusBlastRadiusNamespace (readonly)

Returns client.blast_radius.

Returns:



15749
15750
15751
# File 'lib/infrawrench/client.rb', line 15749

def blast_radius
  @blast_radius
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



15751
15752
15753
# File 'lib/infrawrench/client.rb', line 15751

def budgets
  @budgets
end

#business_metricsBusinessMetricsNamespace (readonly)

Returns client.business_metrics.

Returns:



15753
15754
15755
# File 'lib/infrawrench/client.rb', line 15753

def business_metrics
  @business_metrics
end

#calendarCalendarNamespace (readonly)

Returns client.calendar.

Returns:



15755
15756
15757
# File 'lib/infrawrench/client.rb', line 15755

def calendar
  @calendar
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



15757
15758
15759
# File 'lib/infrawrench/client.rb', line 15757

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



15759
15760
15761
# File 'lib/infrawrench/client.rb', line 15759

def changes
  @changes
end

#chatChatNamespace (readonly)

Returns client.chat.

Returns:



15761
15762
15763
# File 'lib/infrawrench/client.rb', line 15761

def chat
  @chat
end

#commitmentsCommitmentsNamespace (readonly)

Returns client.commitments.

Returns:



15763
15764
15765
# File 'lib/infrawrench/client.rb', line 15763

def commitments
  @commitments
end

#configConfigNamespace (readonly)

Returns client.config.

Returns:



15765
15766
15767
# File 'lib/infrawrench/client.rb', line 15765

def config
  @config
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



15767
15768
15769
# File 'lib/infrawrench/client.rb', line 15767

def connect
  @connect
end

#cost_alertsCostAlertsNamespace (readonly)

Returns client.cost_alerts.

Returns:



15769
15770
15771
# File 'lib/infrawrench/client.rb', line 15769

def cost_alerts
  @cost_alerts
end

#cost_annotationsCostAnnotationsNamespace (readonly)

Returns client.cost_annotations.

Returns:



15771
15772
15773
# File 'lib/infrawrench/client.rb', line 15771

def cost_annotations
  @cost_annotations
end

#cost_centresCostCentresNamespace (readonly)

Returns client.cost_centres.

Returns:



15773
15774
15775
# File 'lib/infrawrench/client.rb', line 15773

def cost_centres
  @cost_centres
end

#cost_exportsCostExportsNamespace (readonly)

Returns client.cost_exports.

Returns:



15775
15776
15777
# File 'lib/infrawrench/client.rb', line 15775

def cost_exports
  @cost_exports
end

#cost_report_foldersCostReportFoldersNamespace (readonly)

Returns client.cost_report_folders.

Returns:



15777
15778
15779
# File 'lib/infrawrench/client.rb', line 15777

def cost_report_folders
  @cost_report_folders
end

#cost_report_notificationsCostReportNotificationsNamespace (readonly)

Returns client.cost_report_notifications.

Returns:



15779
15780
15781
# File 'lib/infrawrench/client.rb', line 15779

def cost_report_notifications
  @cost_report_notifications
end

#cost_reportsCostReportsNamespace (readonly)

Returns client.cost_reports.

Returns:



15781
15782
15783
# File 'lib/infrawrench/client.rb', line 15781

def cost_reports
  @cost_reports
end

#cost_scenariosCostScenariosNamespace (readonly)

Returns client.cost_scenarios.

Returns:



15783
15784
15785
# File 'lib/infrawrench/client.rb', line 15783

def cost_scenarios
  @cost_scenarios
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



15785
15786
15787
# File 'lib/infrawrench/client.rb', line 15785

def costs
  @costs
end

#credential_hygieneCredentialHygieneNamespace (readonly)

Returns client.credential_hygiene.

Returns:



15787
15788
15789
# File 'lib/infrawrench/client.rb', line 15787

def credential_hygiene
  @credential_hygiene
end

#creditsCreditsNamespace (readonly)

Returns client.credits.

Returns:



15789
15790
15791
# File 'lib/infrawrench/client.rb', line 15789

def credits
  @credits
end

#currencyCurrencyNamespace (readonly)

Returns client.currency.

Returns:



15791
15792
15793
# File 'lib/infrawrench/client.rb', line 15791

def currency
  @currency
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



15793
15794
15795
# File 'lib/infrawrench/client.rb', line 15793

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



15795
15796
15797
# File 'lib/infrawrench/client.rb', line 15795

def dashboards
  @dashboards
end

#dependency_graphDependencyGraphNamespace (readonly)

Returns client.dependency_graph.

Returns:



15797
15798
15799
# File 'lib/infrawrench/client.rb', line 15797

def dependency_graph
  @dependency_graph
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



15799
15800
15801
# File 'lib/infrawrench/client.rb', line 15799

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



15801
15802
15803
# File 'lib/infrawrench/client.rb', line 15801

def digest
  @digest
end

#dnsDnsNamespace (readonly)

Returns client.dns.

Returns:



15803
15804
15805
# File 'lib/infrawrench/client.rb', line 15803

def dns
  @dns
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



15805
15806
15807
# File 'lib/infrawrench/client.rb', line 15805

def docker
  @docker
end

#environment_diffEnvironmentDiffNamespace (readonly)

Returns client.environment_diff.

Returns:



15807
15808
15809
# File 'lib/infrawrench/client.rb', line 15807

def environment_diff
  @environment_diff
end

#environmentsEnvironmentsNamespace (readonly)

Returns client.environments.

Returns:



15809
15810
15811
# File 'lib/infrawrench/client.rb', line 15809

def environments
  @environments
end

#expiringExpiringNamespace (readonly)

Returns client.expiring.

Returns:



15811
15812
15813
# File 'lib/infrawrench/client.rb', line 15811

def expiring
  @expiring
end

#iacIacNamespace (readonly)

Returns client.iac.

Returns:



15813
15814
15815
# File 'lib/infrawrench/client.rb', line 15813

def iac
  @iac
end

#incidentsIncidentsNamespace (readonly)

Returns client.incidents.

Returns:



15815
15816
15817
# File 'lib/infrawrench/client.rb', line 15815

def incidents
  @incidents
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



15817
15818
15819
# File 'lib/infrawrench/client.rb', line 15817

def invitations
  @invitations
end

#invoicesInvoicesNamespace (readonly)

Returns client.invoices.

Returns:



15819
15820
15821
# File 'lib/infrawrench/client.rb', line 15819

def invoices
  @invoices
end

#jiraJiraNamespace (readonly)

Returns client.jira.

Returns:



15821
15822
15823
# File 'lib/infrawrench/client.rb', line 15821

def jira
  @jira
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



15823
15824
15825
# File 'lib/infrawrench/client.rb', line 15823

def kv
  @kv
end

#leasesLeasesNamespace (readonly)

Returns client.leases.

Returns:



15825
15826
15827
# File 'lib/infrawrench/client.rb', line 15825

def leases
  @leases
end

#linearLinearNamespace (readonly)

Returns client.linear.

Returns:



15827
15828
15829
# File 'lib/infrawrench/client.rb', line 15827

def linear
  @linear
end

#log_workspacesLogWorkspacesNamespace (readonly)

Returns client.log_workspaces.

Returns:



15829
15830
15831
# File 'lib/infrawrench/client.rb', line 15829

def log_workspaces
  @log_workspaces
end

#managed_accountsManagedAccountsNamespace (readonly)

Returns client.managed_accounts.

Returns:



15831
15832
15833
# File 'lib/infrawrench/client.rb', line 15831

def managed_accounts
  @managed_accounts
end

#metric_alertsMetricAlertsNamespace (readonly)

Returns client.metric_alerts.

Returns:



15833
15834
15835
# File 'lib/infrawrench/client.rb', line 15833

def metric_alerts
  @metric_alerts
end

#momentMomentNamespace (readonly)

Returns client.moment.

Returns:



15835
15836
15837
# File 'lib/infrawrench/client.rb', line 15835

def moment
  @moment
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



15837
15838
15839
# File 'lib/infrawrench/client.rb', line 15837

def msteams
  @msteams
end

#network_flowsNetworkFlowsNamespace (readonly)

Returns client.network_flows.

Returns:



15839
15840
15841
# File 'lib/infrawrench/client.rb', line 15839

def network_flows
  @network_flows
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



15841
15842
15843
# File 'lib/infrawrench/client.rb', line 15841

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



15843
15844
15845
# File 'lib/infrawrench/client.rb', line 15843

def orphans
  @orphans
end

#ownershipOwnershipNamespace (readonly)

Returns client.ownership.

Returns:



15845
15846
15847
# File 'lib/infrawrench/client.rb', line 15845

def ownership
  @ownership
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



15847
15848
15849
# File 'lib/infrawrench/client.rb', line 15847

def pages
  @pages
end

#posturePostureNamespace (readonly)

Returns client.posture.

Returns:



15849
15850
15851
# File 'lib/infrawrench/client.rb', line 15849

def posture
  @posture
end

#probesProbesNamespace (readonly)

Returns client.probes.

Returns:



15851
15852
15853
# File 'lib/infrawrench/client.rb', line 15851

def probes
  @probes
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



15853
15854
15855
# File 'lib/infrawrench/client.rb', line 15853

def profile
  @profile
end

#quotasQuotasNamespace (readonly)

Returns client.quotas.

Returns:



15855
15856
15857
# File 'lib/infrawrench/client.rb', line 15855

def quotas
  @quotas
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



15857
15858
15859
# File 'lib/infrawrench/client.rb', line 15857

def resources
  @resources
end

#rightsizingRightsizingNamespace (readonly)

Returns client.rightsizing.

Returns:



15859
15860
15861
# File 'lib/infrawrench/client.rb', line 15859

def rightsizing
  @rightsizing
end

#saved_cost_filtersSavedCostFiltersNamespace (readonly)

Returns client.saved_cost_filters.

Returns:



15861
15862
15863
# File 'lib/infrawrench/client.rb', line 15861

def saved_cost_filters
  @saved_cost_filters
end

#schedulesSchedulesNamespace (readonly)

Returns client.schedules.

Returns:



15863
15864
15865
# File 'lib/infrawrench/client.rb', line 15863

def schedules
  @schedules
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



15865
15866
15867
# File 'lib/infrawrench/client.rb', line 15865

def search
  @search
end

#session_recordingsSessionRecordingsNamespace (readonly)

Returns client.session_recordings.

Returns:



15867
15868
15869
# File 'lib/infrawrench/client.rb', line 15867

def session_recordings
  @session_recordings
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



15869
15870
15871
# File 'lib/infrawrench/client.rb', line 15869

def sftp
  @sftp
end

#shared_consolesSharedConsolesNamespace (readonly)

Returns client.shared_consoles.

Returns:



15871
15872
15873
# File 'lib/infrawrench/client.rb', line 15871

def shared_consoles
  @shared_consoles
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



15873
15874
15875
# File 'lib/infrawrench/client.rb', line 15873

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



15875
15876
15877
# File 'lib/infrawrench/client.rb', line 15875

def sql
  @sql
end

#ssh_fanoutSshFanoutNamespace (readonly)

Returns client.ssh_fanout.

Returns:



15877
15878
15879
# File 'lib/infrawrench/client.rb', line 15877

def ssh_fanout
  @ssh_fanout
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



15879
15880
15881
# File 'lib/infrawrench/client.rb', line 15879

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



15881
15882
15883
# File 'lib/infrawrench/client.rb', line 15881

def ssh_tunnels
  @ssh_tunnels
end

#statusStatusNamespace (readonly)

Returns client.status.

Returns:



15883
15884
15885
# File 'lib/infrawrench/client.rb', line 15883

def status
  @status
end

#status_incidentsStatusIncidentsNamespace (readonly)

Returns client.status_incidents.

Returns:



15885
15886
15887
# File 'lib/infrawrench/client.rb', line 15885

def status_incidents
  @status_incidents
end

#status_pagesStatusPagesNamespace (readonly)

Returns client.status_pages.

Returns:



15887
15888
15889
# File 'lib/infrawrench/client.rb', line 15887

def status_pages
  @status_pages
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



15889
15890
15891
# File 'lib/infrawrench/client.rb', line 15889

def storage
  @storage
end

#tag_policyTagPolicyNamespace (readonly)

Returns client.tag_policy.

Returns:



15891
15892
15893
# File 'lib/infrawrench/client.rb', line 15891

def tag_policy
  @tag_policy
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



15893
15894
15895
# File 'lib/infrawrench/client.rb', line 15893

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



15713
15714
15715
# File 'lib/infrawrench/client.rb', line 15713

def transport
  @transport
end

#wallboardWallboardNamespace (readonly)

Returns client.wallboard.

Returns:



15895
15896
15897
# File 'lib/infrawrench/client.rb', line 15895

def wallboard
  @wallboard
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



15897
15898
15899
# File 'lib/infrawrench/client.rb', line 15897

def workflow_approvals
  @workflow_approvals
end

#workflow_secretsWorkflowSecretsNamespace (readonly)

Returns client.workflow_secrets.

Returns:



15899
15900
15901
# File 'lib/infrawrench/client.rb', line 15899

def workflow_secrets
  @workflow_secrets
end

#workflowsWorkflowsNamespace (readonly)

Returns client.workflows.

Returns:



15901
15902
15903
# File 'lib/infrawrench/client.rb', line 15901

def workflows
  @workflows
end