Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.access_requests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


15607
15608
15609
15610
15611
15612
15613
15614
15615
15616
15617
15618
15619
15620
15621
15622
15623
15624
15625
15626
15627
15628
15629
15630
15631
15632
15633
15634
15635
15636
15637
15638
15639
15640
15641
15642
15643
15644
15645
15646
15647
15648
15649
15650
15651
15652
15653
15654
15655
15656
15657
15658
15659
15660
15661
15662
15663
15664
15665
15666
15667
15668
15669
15670
15671
15672
15673
15674
15675
15676
15677
15678
15679
15680
15681
15682
15683
15684
15685
15686
15687
15688
15689
15690
15691
15692
15693
15694
15695
15696
15697
15698
15699
15700
# File 'lib/infrawrench/client.rb', line 15607

def initialize(**options)
  @transport = Transport.new(**options)
  @access_requests = AccessRequestsNamespace.new(@transport)
  @access_review = AccessReviewNamespace.new(@transport)
  @accounts = AccountsNamespace.new(@transport)
  @agent = AgentNamespace.new(@transport)
  @agent_registrations = AgentRegistrationsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @alert_rules = AlertRulesNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @backups = BackupsNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @billing_rules = BillingRulesNamespace.new(@transport)
  @blast_radius = BlastRadiusNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @business_metrics = BusinessMetricsNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @chat = ChatNamespace.new(@transport)
  @commitments = CommitmentsNamespace.new(@transport)
  @config = ConfigNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @cost_alerts = CostAlertsNamespace.new(@transport)
  @cost_annotations = CostAnnotationsNamespace.new(@transport)
  @cost_centres = CostCentresNamespace.new(@transport)
  @cost_exports = CostExportsNamespace.new(@transport)
  @cost_report_folders = CostReportFoldersNamespace.new(@transport)
  @cost_report_notifications = CostReportNotificationsNamespace.new(@transport)
  @cost_reports = CostReportsNamespace.new(@transport)
  @cost_scenarios = CostScenariosNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @credential_hygiene = CredentialHygieneNamespace.new(@transport)
  @credits = CreditsNamespace.new(@transport)
  @currency = CurrencyNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @dependency_graph = DependencyGraphNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @dns = DnsNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @environment_diff = EnvironmentDiffNamespace.new(@transport)
  @environments = EnvironmentsNamespace.new(@transport)
  @expiring = ExpiringNamespace.new(@transport)
  @iac = IacNamespace.new(@transport)
  @incidents = IncidentsNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @invoices = InvoicesNamespace.new(@transport)
  @jira = JiraNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @leases = LeasesNamespace.new(@transport)
  @linear = LinearNamespace.new(@transport)
  @log_workspaces = LogWorkspacesNamespace.new(@transport)
  @managed_accounts = ManagedAccountsNamespace.new(@transport)
  @metric_alerts = MetricAlertsNamespace.new(@transport)
  @moment = MomentNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @network_flows = NetworkFlowsNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @ownership = OwnershipNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @posture = PostureNamespace.new(@transport)
  @probes = ProbesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @quotas = QuotasNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @rightsizing = RightsizingNamespace.new(@transport)
  @saved_cost_filters = SavedCostFiltersNamespace.new(@transport)
  @schedules = SchedulesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @session_recordings = SessionRecordingsNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @shared_consoles = SharedConsolesNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_fanout = SshFanoutNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @status = StatusNamespace.new(@transport)
  @status_incidents = StatusIncidentsNamespace.new(@transport)
  @status_pages = StatusPagesNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @tag_policy = TagPolicyNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
  @workflow_secrets = WorkflowSecretsNamespace.new(@transport)
  @workflows = WorkflowsNamespace.new(@transport)
end

Instance Attribute Details

#access_requestsAccessRequestsNamespace (readonly)

Returns client.access_requests.

Returns:



15422
15423
15424
# File 'lib/infrawrench/client.rb', line 15422

def access_requests
  @access_requests
end

#access_reviewAccessReviewNamespace (readonly)

Returns client.access_review.

Returns:



15424
15425
15426
# File 'lib/infrawrench/client.rb', line 15424

def access_review
  @access_review
end

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



15426
15427
15428
# File 'lib/infrawrench/client.rb', line 15426

def accounts
  @accounts
end

#agentAgentNamespace (readonly)

Returns client.agent.

Returns:



15428
15429
15430
# File 'lib/infrawrench/client.rb', line 15428

def agent
  @agent
end

#agent_registrationsAgentRegistrationsNamespace (readonly)

Returns client.agent_registrations.

Returns:



15430
15431
15432
# File 'lib/infrawrench/client.rb', line 15430

def agent_registrations
  @agent_registrations
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



15432
15433
15434
# File 'lib/infrawrench/client.rb', line 15432

def agents
  @agents
end

#alert_rulesAlertRulesNamespace (readonly)

Returns client.alert_rules.

Returns:



15434
15435
15436
# File 'lib/infrawrench/client.rb', line 15434

def alert_rules
  @alert_rules
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



15436
15437
15438
# File 'lib/infrawrench/client.rb', line 15436

def api_keys
  @api_keys
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



15438
15439
15440
# File 'lib/infrawrench/client.rb', line 15438

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



15440
15441
15442
# File 'lib/infrawrench/client.rb', line 15440

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



15442
15443
15444
# File 'lib/infrawrench/client.rb', line 15442

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



15444
15445
15446
# File 'lib/infrawrench/client.rb', line 15444

def auth
  @auth
end

#backupsBackupsNamespace (readonly)

Returns client.backups.

Returns:



15446
15447
15448
# File 'lib/infrawrench/client.rb', line 15446

def backups
  @backups
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



15448
15449
15450
# File 'lib/infrawrench/client.rb', line 15448

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



15450
15451
15452
# File 'lib/infrawrench/client.rb', line 15450

def billing
  @billing
end

#billing_rulesBillingRulesNamespace (readonly)

Returns client.billing_rules.

Returns:



15452
15453
15454
# File 'lib/infrawrench/client.rb', line 15452

def billing_rules
  @billing_rules
end

#blast_radiusBlastRadiusNamespace (readonly)

Returns client.blast_radius.

Returns:



15454
15455
15456
# File 'lib/infrawrench/client.rb', line 15454

def blast_radius
  @blast_radius
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



15456
15457
15458
# File 'lib/infrawrench/client.rb', line 15456

def budgets
  @budgets
end

#business_metricsBusinessMetricsNamespace (readonly)

Returns client.business_metrics.

Returns:



15458
15459
15460
# File 'lib/infrawrench/client.rb', line 15458

def business_metrics
  @business_metrics
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



15460
15461
15462
# File 'lib/infrawrench/client.rb', line 15460

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



15462
15463
15464
# File 'lib/infrawrench/client.rb', line 15462

def changes
  @changes
end

#chatChatNamespace (readonly)

Returns client.chat.

Returns:



15464
15465
15466
# File 'lib/infrawrench/client.rb', line 15464

def chat
  @chat
end

#commitmentsCommitmentsNamespace (readonly)

Returns client.commitments.

Returns:



15466
15467
15468
# File 'lib/infrawrench/client.rb', line 15466

def commitments
  @commitments
end

#configConfigNamespace (readonly)

Returns client.config.

Returns:



15468
15469
15470
# File 'lib/infrawrench/client.rb', line 15468

def config
  @config
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



15470
15471
15472
# File 'lib/infrawrench/client.rb', line 15470

def connect
  @connect
end

#cost_alertsCostAlertsNamespace (readonly)

Returns client.cost_alerts.

Returns:



15472
15473
15474
# File 'lib/infrawrench/client.rb', line 15472

def cost_alerts
  @cost_alerts
end

#cost_annotationsCostAnnotationsNamespace (readonly)

Returns client.cost_annotations.

Returns:



15474
15475
15476
# File 'lib/infrawrench/client.rb', line 15474

def cost_annotations
  @cost_annotations
end

#cost_centresCostCentresNamespace (readonly)

Returns client.cost_centres.

Returns:



15476
15477
15478
# File 'lib/infrawrench/client.rb', line 15476

def cost_centres
  @cost_centres
end

#cost_exportsCostExportsNamespace (readonly)

Returns client.cost_exports.

Returns:



15478
15479
15480
# File 'lib/infrawrench/client.rb', line 15478

def cost_exports
  @cost_exports
end

#cost_report_foldersCostReportFoldersNamespace (readonly)

Returns client.cost_report_folders.

Returns:



15480
15481
15482
# File 'lib/infrawrench/client.rb', line 15480

def cost_report_folders
  @cost_report_folders
end

#cost_report_notificationsCostReportNotificationsNamespace (readonly)

Returns client.cost_report_notifications.

Returns:



15482
15483
15484
# File 'lib/infrawrench/client.rb', line 15482

def cost_report_notifications
  @cost_report_notifications
end

#cost_reportsCostReportsNamespace (readonly)

Returns client.cost_reports.

Returns:



15484
15485
15486
# File 'lib/infrawrench/client.rb', line 15484

def cost_reports
  @cost_reports
end

#cost_scenariosCostScenariosNamespace (readonly)

Returns client.cost_scenarios.

Returns:



15486
15487
15488
# File 'lib/infrawrench/client.rb', line 15486

def cost_scenarios
  @cost_scenarios
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



15488
15489
15490
# File 'lib/infrawrench/client.rb', line 15488

def costs
  @costs
end

#credential_hygieneCredentialHygieneNamespace (readonly)

Returns client.credential_hygiene.

Returns:



15490
15491
15492
# File 'lib/infrawrench/client.rb', line 15490

def credential_hygiene
  @credential_hygiene
end

#creditsCreditsNamespace (readonly)

Returns client.credits.

Returns:



15492
15493
15494
# File 'lib/infrawrench/client.rb', line 15492

def credits
  @credits
end

#currencyCurrencyNamespace (readonly)

Returns client.currency.

Returns:



15494
15495
15496
# File 'lib/infrawrench/client.rb', line 15494

def currency
  @currency
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



15496
15497
15498
# File 'lib/infrawrench/client.rb', line 15496

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



15498
15499
15500
# File 'lib/infrawrench/client.rb', line 15498

def dashboards
  @dashboards
end

#dependency_graphDependencyGraphNamespace (readonly)

Returns client.dependency_graph.

Returns:



15500
15501
15502
# File 'lib/infrawrench/client.rb', line 15500

def dependency_graph
  @dependency_graph
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



15502
15503
15504
# File 'lib/infrawrench/client.rb', line 15502

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



15504
15505
15506
# File 'lib/infrawrench/client.rb', line 15504

def digest
  @digest
end

#dnsDnsNamespace (readonly)

Returns client.dns.

Returns:



15506
15507
15508
# File 'lib/infrawrench/client.rb', line 15506

def dns
  @dns
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



15508
15509
15510
# File 'lib/infrawrench/client.rb', line 15508

def docker
  @docker
end

#environment_diffEnvironmentDiffNamespace (readonly)

Returns client.environment_diff.

Returns:



15510
15511
15512
# File 'lib/infrawrench/client.rb', line 15510

def environment_diff
  @environment_diff
end

#environmentsEnvironmentsNamespace (readonly)

Returns client.environments.

Returns:



15512
15513
15514
# File 'lib/infrawrench/client.rb', line 15512

def environments
  @environments
end

#expiringExpiringNamespace (readonly)

Returns client.expiring.

Returns:



15514
15515
15516
# File 'lib/infrawrench/client.rb', line 15514

def expiring
  @expiring
end

#iacIacNamespace (readonly)

Returns client.iac.

Returns:



15516
15517
15518
# File 'lib/infrawrench/client.rb', line 15516

def iac
  @iac
end

#incidentsIncidentsNamespace (readonly)

Returns client.incidents.

Returns:



15518
15519
15520
# File 'lib/infrawrench/client.rb', line 15518

def incidents
  @incidents
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



15520
15521
15522
# File 'lib/infrawrench/client.rb', line 15520

def invitations
  @invitations
end

#invoicesInvoicesNamespace (readonly)

Returns client.invoices.

Returns:



15522
15523
15524
# File 'lib/infrawrench/client.rb', line 15522

def invoices
  @invoices
end

#jiraJiraNamespace (readonly)

Returns client.jira.

Returns:



15524
15525
15526
# File 'lib/infrawrench/client.rb', line 15524

def jira
  @jira
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



15526
15527
15528
# File 'lib/infrawrench/client.rb', line 15526

def kv
  @kv
end

#leasesLeasesNamespace (readonly)

Returns client.leases.

Returns:



15528
15529
15530
# File 'lib/infrawrench/client.rb', line 15528

def leases
  @leases
end

#linearLinearNamespace (readonly)

Returns client.linear.

Returns:



15530
15531
15532
# File 'lib/infrawrench/client.rb', line 15530

def linear
  @linear
end

#log_workspacesLogWorkspacesNamespace (readonly)

Returns client.log_workspaces.

Returns:



15532
15533
15534
# File 'lib/infrawrench/client.rb', line 15532

def log_workspaces
  @log_workspaces
end

#managed_accountsManagedAccountsNamespace (readonly)

Returns client.managed_accounts.

Returns:



15534
15535
15536
# File 'lib/infrawrench/client.rb', line 15534

def managed_accounts
  @managed_accounts
end

#metric_alertsMetricAlertsNamespace (readonly)

Returns client.metric_alerts.

Returns:



15536
15537
15538
# File 'lib/infrawrench/client.rb', line 15536

def metric_alerts
  @metric_alerts
end

#momentMomentNamespace (readonly)

Returns client.moment.

Returns:



15538
15539
15540
# File 'lib/infrawrench/client.rb', line 15538

def moment
  @moment
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



15540
15541
15542
# File 'lib/infrawrench/client.rb', line 15540

def msteams
  @msteams
end

#network_flowsNetworkFlowsNamespace (readonly)

Returns client.network_flows.

Returns:



15542
15543
15544
# File 'lib/infrawrench/client.rb', line 15542

def network_flows
  @network_flows
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



15544
15545
15546
# File 'lib/infrawrench/client.rb', line 15544

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



15546
15547
15548
# File 'lib/infrawrench/client.rb', line 15546

def orphans
  @orphans
end

#ownershipOwnershipNamespace (readonly)

Returns client.ownership.

Returns:



15548
15549
15550
# File 'lib/infrawrench/client.rb', line 15548

def ownership
  @ownership
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



15550
15551
15552
# File 'lib/infrawrench/client.rb', line 15550

def pages
  @pages
end

#posturePostureNamespace (readonly)

Returns client.posture.

Returns:



15552
15553
15554
# File 'lib/infrawrench/client.rb', line 15552

def posture
  @posture
end

#probesProbesNamespace (readonly)

Returns client.probes.

Returns:



15554
15555
15556
# File 'lib/infrawrench/client.rb', line 15554

def probes
  @probes
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



15556
15557
15558
# File 'lib/infrawrench/client.rb', line 15556

def profile
  @profile
end

#quotasQuotasNamespace (readonly)

Returns client.quotas.

Returns:



15558
15559
15560
# File 'lib/infrawrench/client.rb', line 15558

def quotas
  @quotas
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



15560
15561
15562
# File 'lib/infrawrench/client.rb', line 15560

def resources
  @resources
end

#rightsizingRightsizingNamespace (readonly)

Returns client.rightsizing.

Returns:



15562
15563
15564
# File 'lib/infrawrench/client.rb', line 15562

def rightsizing
  @rightsizing
end

#saved_cost_filtersSavedCostFiltersNamespace (readonly)

Returns client.saved_cost_filters.

Returns:



15564
15565
15566
# File 'lib/infrawrench/client.rb', line 15564

def saved_cost_filters
  @saved_cost_filters
end

#schedulesSchedulesNamespace (readonly)

Returns client.schedules.

Returns:



15566
15567
15568
# File 'lib/infrawrench/client.rb', line 15566

def schedules
  @schedules
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



15568
15569
15570
# File 'lib/infrawrench/client.rb', line 15568

def search
  @search
end

#session_recordingsSessionRecordingsNamespace (readonly)

Returns client.session_recordings.

Returns:



15570
15571
15572
# File 'lib/infrawrench/client.rb', line 15570

def session_recordings
  @session_recordings
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



15572
15573
15574
# File 'lib/infrawrench/client.rb', line 15572

def sftp
  @sftp
end

#shared_consolesSharedConsolesNamespace (readonly)

Returns client.shared_consoles.

Returns:



15574
15575
15576
# File 'lib/infrawrench/client.rb', line 15574

def shared_consoles
  @shared_consoles
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



15576
15577
15578
# File 'lib/infrawrench/client.rb', line 15576

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



15578
15579
15580
# File 'lib/infrawrench/client.rb', line 15578

def sql
  @sql
end

#ssh_fanoutSshFanoutNamespace (readonly)

Returns client.ssh_fanout.

Returns:



15580
15581
15582
# File 'lib/infrawrench/client.rb', line 15580

def ssh_fanout
  @ssh_fanout
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



15582
15583
15584
# File 'lib/infrawrench/client.rb', line 15582

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



15584
15585
15586
# File 'lib/infrawrench/client.rb', line 15584

def ssh_tunnels
  @ssh_tunnels
end

#statusStatusNamespace (readonly)

Returns client.status.

Returns:



15586
15587
15588
# File 'lib/infrawrench/client.rb', line 15586

def status
  @status
end

#status_incidentsStatusIncidentsNamespace (readonly)

Returns client.status_incidents.

Returns:



15588
15589
15590
# File 'lib/infrawrench/client.rb', line 15588

def status_incidents
  @status_incidents
end

#status_pagesStatusPagesNamespace (readonly)

Returns client.status_pages.

Returns:



15590
15591
15592
# File 'lib/infrawrench/client.rb', line 15590

def status_pages
  @status_pages
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



15592
15593
15594
# File 'lib/infrawrench/client.rb', line 15592

def storage
  @storage
end

#tag_policyTagPolicyNamespace (readonly)

Returns client.tag_policy.

Returns:



15594
15595
15596
# File 'lib/infrawrench/client.rb', line 15594

def tag_policy
  @tag_policy
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



15596
15597
15598
# File 'lib/infrawrench/client.rb', line 15596

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



15420
15421
15422
# File 'lib/infrawrench/client.rb', line 15420

def transport
  @transport
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



15598
15599
15600
# File 'lib/infrawrench/client.rb', line 15598

def workflow_approvals
  @workflow_approvals
end

#workflow_secretsWorkflowSecretsNamespace (readonly)

Returns client.workflow_secrets.

Returns:



15600
15601
15602
# File 'lib/infrawrench/client.rb', line 15600

def workflow_secrets
  @workflow_secrets
end

#workflowsWorkflowsNamespace (readonly)

Returns client.workflows.

Returns:



15602
15603
15604
# File 'lib/infrawrench/client.rb', line 15602

def workflows
  @workflows
end