Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.access_requests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


15348
15349
15350
15351
15352
15353
15354
15355
15356
15357
15358
15359
15360
15361
15362
15363
15364
15365
15366
15367
15368
15369
15370
15371
15372
15373
15374
15375
15376
15377
15378
15379
15380
15381
15382
15383
15384
15385
15386
15387
15388
15389
15390
15391
15392
15393
15394
15395
15396
15397
15398
15399
15400
15401
15402
15403
15404
15405
15406
15407
15408
15409
15410
15411
15412
15413
15414
15415
15416
15417
15418
15419
15420
15421
15422
15423
15424
15425
15426
15427
15428
15429
15430
15431
15432
15433
15434
15435
15436
15437
15438
15439
# File 'lib/infrawrench/client.rb', line 15348

def initialize(**options)
  @transport = Transport.new(**options)
  @access_requests = AccessRequestsNamespace.new(@transport)
  @access_review = AccessReviewNamespace.new(@transport)
  @accounts = AccountsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @alert_rules = AlertRulesNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @backups = BackupsNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @billing_rules = BillingRulesNamespace.new(@transport)
  @blast_radius = BlastRadiusNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @business_metrics = BusinessMetricsNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @chat = ChatNamespace.new(@transport)
  @commitments = CommitmentsNamespace.new(@transport)
  @config = ConfigNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @cost_alerts = CostAlertsNamespace.new(@transport)
  @cost_annotations = CostAnnotationsNamespace.new(@transport)
  @cost_centres = CostCentresNamespace.new(@transport)
  @cost_exports = CostExportsNamespace.new(@transport)
  @cost_report_folders = CostReportFoldersNamespace.new(@transport)
  @cost_report_notifications = CostReportNotificationsNamespace.new(@transport)
  @cost_reports = CostReportsNamespace.new(@transport)
  @cost_scenarios = CostScenariosNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @credential_hygiene = CredentialHygieneNamespace.new(@transport)
  @credits = CreditsNamespace.new(@transport)
  @currency = CurrencyNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @dependency_graph = DependencyGraphNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @dns = DnsNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @environment_diff = EnvironmentDiffNamespace.new(@transport)
  @environments = EnvironmentsNamespace.new(@transport)
  @expiring = ExpiringNamespace.new(@transport)
  @iac = IacNamespace.new(@transport)
  @incidents = IncidentsNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @invoices = InvoicesNamespace.new(@transport)
  @jira = JiraNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @leases = LeasesNamespace.new(@transport)
  @linear = LinearNamespace.new(@transport)
  @log_workspaces = LogWorkspacesNamespace.new(@transport)
  @managed_accounts = ManagedAccountsNamespace.new(@transport)
  @metric_alerts = MetricAlertsNamespace.new(@transport)
  @moment = MomentNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @network_flows = NetworkFlowsNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @ownership = OwnershipNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @posture = PostureNamespace.new(@transport)
  @probes = ProbesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @quotas = QuotasNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @rightsizing = RightsizingNamespace.new(@transport)
  @saved_cost_filters = SavedCostFiltersNamespace.new(@transport)
  @schedules = SchedulesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @session_recordings = SessionRecordingsNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @shared_consoles = SharedConsolesNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_fanout = SshFanoutNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @status = StatusNamespace.new(@transport)
  @status_incidents = StatusIncidentsNamespace.new(@transport)
  @status_pages = StatusPagesNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @tag_policy = TagPolicyNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
  @workflow_secrets = WorkflowSecretsNamespace.new(@transport)
  @workflows = WorkflowsNamespace.new(@transport)
end

Instance Attribute Details

#access_requestsAccessRequestsNamespace (readonly)

Returns client.access_requests.

Returns:



15167
15168
15169
# File 'lib/infrawrench/client.rb', line 15167

def access_requests
  @access_requests
end

#access_reviewAccessReviewNamespace (readonly)

Returns client.access_review.

Returns:



15169
15170
15171
# File 'lib/infrawrench/client.rb', line 15169

def access_review
  @access_review
end

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



15171
15172
15173
# File 'lib/infrawrench/client.rb', line 15171

def accounts
  @accounts
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



15173
15174
15175
# File 'lib/infrawrench/client.rb', line 15173

def agents
  @agents
end

#alert_rulesAlertRulesNamespace (readonly)

Returns client.alert_rules.

Returns:



15175
15176
15177
# File 'lib/infrawrench/client.rb', line 15175

def alert_rules
  @alert_rules
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



15177
15178
15179
# File 'lib/infrawrench/client.rb', line 15177

def api_keys
  @api_keys
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



15179
15180
15181
# File 'lib/infrawrench/client.rb', line 15179

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



15181
15182
15183
# File 'lib/infrawrench/client.rb', line 15181

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



15183
15184
15185
# File 'lib/infrawrench/client.rb', line 15183

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



15185
15186
15187
# File 'lib/infrawrench/client.rb', line 15185

def auth
  @auth
end

#backupsBackupsNamespace (readonly)

Returns client.backups.

Returns:



15187
15188
15189
# File 'lib/infrawrench/client.rb', line 15187

def backups
  @backups
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



15189
15190
15191
# File 'lib/infrawrench/client.rb', line 15189

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



15191
15192
15193
# File 'lib/infrawrench/client.rb', line 15191

def billing
  @billing
end

#billing_rulesBillingRulesNamespace (readonly)

Returns client.billing_rules.

Returns:



15193
15194
15195
# File 'lib/infrawrench/client.rb', line 15193

def billing_rules
  @billing_rules
end

#blast_radiusBlastRadiusNamespace (readonly)

Returns client.blast_radius.

Returns:



15195
15196
15197
# File 'lib/infrawrench/client.rb', line 15195

def blast_radius
  @blast_radius
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



15197
15198
15199
# File 'lib/infrawrench/client.rb', line 15197

def budgets
  @budgets
end

#business_metricsBusinessMetricsNamespace (readonly)

Returns client.business_metrics.

Returns:



15199
15200
15201
# File 'lib/infrawrench/client.rb', line 15199

def business_metrics
  @business_metrics
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



15201
15202
15203
# File 'lib/infrawrench/client.rb', line 15201

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



15203
15204
15205
# File 'lib/infrawrench/client.rb', line 15203

def changes
  @changes
end

#chatChatNamespace (readonly)

Returns client.chat.

Returns:



15205
15206
15207
# File 'lib/infrawrench/client.rb', line 15205

def chat
  @chat
end

#commitmentsCommitmentsNamespace (readonly)

Returns client.commitments.

Returns:



15207
15208
15209
# File 'lib/infrawrench/client.rb', line 15207

def commitments
  @commitments
end

#configConfigNamespace (readonly)

Returns client.config.

Returns:



15209
15210
15211
# File 'lib/infrawrench/client.rb', line 15209

def config
  @config
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



15211
15212
15213
# File 'lib/infrawrench/client.rb', line 15211

def connect
  @connect
end

#cost_alertsCostAlertsNamespace (readonly)

Returns client.cost_alerts.

Returns:



15213
15214
15215
# File 'lib/infrawrench/client.rb', line 15213

def cost_alerts
  @cost_alerts
end

#cost_annotationsCostAnnotationsNamespace (readonly)

Returns client.cost_annotations.

Returns:



15215
15216
15217
# File 'lib/infrawrench/client.rb', line 15215

def cost_annotations
  @cost_annotations
end

#cost_centresCostCentresNamespace (readonly)

Returns client.cost_centres.

Returns:



15217
15218
15219
# File 'lib/infrawrench/client.rb', line 15217

def cost_centres
  @cost_centres
end

#cost_exportsCostExportsNamespace (readonly)

Returns client.cost_exports.

Returns:



15219
15220
15221
# File 'lib/infrawrench/client.rb', line 15219

def cost_exports
  @cost_exports
end

#cost_report_foldersCostReportFoldersNamespace (readonly)

Returns client.cost_report_folders.

Returns:



15221
15222
15223
# File 'lib/infrawrench/client.rb', line 15221

def cost_report_folders
  @cost_report_folders
end

#cost_report_notificationsCostReportNotificationsNamespace (readonly)

Returns client.cost_report_notifications.

Returns:



15223
15224
15225
# File 'lib/infrawrench/client.rb', line 15223

def cost_report_notifications
  @cost_report_notifications
end

#cost_reportsCostReportsNamespace (readonly)

Returns client.cost_reports.

Returns:



15225
15226
15227
# File 'lib/infrawrench/client.rb', line 15225

def cost_reports
  @cost_reports
end

#cost_scenariosCostScenariosNamespace (readonly)

Returns client.cost_scenarios.

Returns:



15227
15228
15229
# File 'lib/infrawrench/client.rb', line 15227

def cost_scenarios
  @cost_scenarios
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



15229
15230
15231
# File 'lib/infrawrench/client.rb', line 15229

def costs
  @costs
end

#credential_hygieneCredentialHygieneNamespace (readonly)

Returns client.credential_hygiene.

Returns:



15231
15232
15233
# File 'lib/infrawrench/client.rb', line 15231

def credential_hygiene
  @credential_hygiene
end

#creditsCreditsNamespace (readonly)

Returns client.credits.

Returns:



15233
15234
15235
# File 'lib/infrawrench/client.rb', line 15233

def credits
  @credits
end

#currencyCurrencyNamespace (readonly)

Returns client.currency.

Returns:



15235
15236
15237
# File 'lib/infrawrench/client.rb', line 15235

def currency
  @currency
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



15237
15238
15239
# File 'lib/infrawrench/client.rb', line 15237

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



15239
15240
15241
# File 'lib/infrawrench/client.rb', line 15239

def dashboards
  @dashboards
end

#dependency_graphDependencyGraphNamespace (readonly)

Returns client.dependency_graph.

Returns:



15241
15242
15243
# File 'lib/infrawrench/client.rb', line 15241

def dependency_graph
  @dependency_graph
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



15243
15244
15245
# File 'lib/infrawrench/client.rb', line 15243

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



15245
15246
15247
# File 'lib/infrawrench/client.rb', line 15245

def digest
  @digest
end

#dnsDnsNamespace (readonly)

Returns client.dns.

Returns:



15247
15248
15249
# File 'lib/infrawrench/client.rb', line 15247

def dns
  @dns
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



15249
15250
15251
# File 'lib/infrawrench/client.rb', line 15249

def docker
  @docker
end

#environment_diffEnvironmentDiffNamespace (readonly)

Returns client.environment_diff.

Returns:



15251
15252
15253
# File 'lib/infrawrench/client.rb', line 15251

def environment_diff
  @environment_diff
end

#environmentsEnvironmentsNamespace (readonly)

Returns client.environments.

Returns:



15253
15254
15255
# File 'lib/infrawrench/client.rb', line 15253

def environments
  @environments
end

#expiringExpiringNamespace (readonly)

Returns client.expiring.

Returns:



15255
15256
15257
# File 'lib/infrawrench/client.rb', line 15255

def expiring
  @expiring
end

#iacIacNamespace (readonly)

Returns client.iac.

Returns:



15257
15258
15259
# File 'lib/infrawrench/client.rb', line 15257

def iac
  @iac
end

#incidentsIncidentsNamespace (readonly)

Returns client.incidents.

Returns:



15259
15260
15261
# File 'lib/infrawrench/client.rb', line 15259

def incidents
  @incidents
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



15261
15262
15263
# File 'lib/infrawrench/client.rb', line 15261

def invitations
  @invitations
end

#invoicesInvoicesNamespace (readonly)

Returns client.invoices.

Returns:



15263
15264
15265
# File 'lib/infrawrench/client.rb', line 15263

def invoices
  @invoices
end

#jiraJiraNamespace (readonly)

Returns client.jira.

Returns:



15265
15266
15267
# File 'lib/infrawrench/client.rb', line 15265

def jira
  @jira
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



15267
15268
15269
# File 'lib/infrawrench/client.rb', line 15267

def kv
  @kv
end

#leasesLeasesNamespace (readonly)

Returns client.leases.

Returns:



15269
15270
15271
# File 'lib/infrawrench/client.rb', line 15269

def leases
  @leases
end

#linearLinearNamespace (readonly)

Returns client.linear.

Returns:



15271
15272
15273
# File 'lib/infrawrench/client.rb', line 15271

def linear
  @linear
end

#log_workspacesLogWorkspacesNamespace (readonly)

Returns client.log_workspaces.

Returns:



15273
15274
15275
# File 'lib/infrawrench/client.rb', line 15273

def log_workspaces
  @log_workspaces
end

#managed_accountsManagedAccountsNamespace (readonly)

Returns client.managed_accounts.

Returns:



15275
15276
15277
# File 'lib/infrawrench/client.rb', line 15275

def managed_accounts
  @managed_accounts
end

#metric_alertsMetricAlertsNamespace (readonly)

Returns client.metric_alerts.

Returns:



15277
15278
15279
# File 'lib/infrawrench/client.rb', line 15277

def metric_alerts
  @metric_alerts
end

#momentMomentNamespace (readonly)

Returns client.moment.

Returns:



15279
15280
15281
# File 'lib/infrawrench/client.rb', line 15279

def moment
  @moment
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



15281
15282
15283
# File 'lib/infrawrench/client.rb', line 15281

def msteams
  @msteams
end

#network_flowsNetworkFlowsNamespace (readonly)

Returns client.network_flows.

Returns:



15283
15284
15285
# File 'lib/infrawrench/client.rb', line 15283

def network_flows
  @network_flows
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



15285
15286
15287
# File 'lib/infrawrench/client.rb', line 15285

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



15287
15288
15289
# File 'lib/infrawrench/client.rb', line 15287

def orphans
  @orphans
end

#ownershipOwnershipNamespace (readonly)

Returns client.ownership.

Returns:



15289
15290
15291
# File 'lib/infrawrench/client.rb', line 15289

def ownership
  @ownership
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



15291
15292
15293
# File 'lib/infrawrench/client.rb', line 15291

def pages
  @pages
end

#posturePostureNamespace (readonly)

Returns client.posture.

Returns:



15293
15294
15295
# File 'lib/infrawrench/client.rb', line 15293

def posture
  @posture
end

#probesProbesNamespace (readonly)

Returns client.probes.

Returns:



15295
15296
15297
# File 'lib/infrawrench/client.rb', line 15295

def probes
  @probes
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



15297
15298
15299
# File 'lib/infrawrench/client.rb', line 15297

def profile
  @profile
end

#quotasQuotasNamespace (readonly)

Returns client.quotas.

Returns:



15299
15300
15301
# File 'lib/infrawrench/client.rb', line 15299

def quotas
  @quotas
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



15301
15302
15303
# File 'lib/infrawrench/client.rb', line 15301

def resources
  @resources
end

#rightsizingRightsizingNamespace (readonly)

Returns client.rightsizing.

Returns:



15303
15304
15305
# File 'lib/infrawrench/client.rb', line 15303

def rightsizing
  @rightsizing
end

#saved_cost_filtersSavedCostFiltersNamespace (readonly)

Returns client.saved_cost_filters.

Returns:



15305
15306
15307
# File 'lib/infrawrench/client.rb', line 15305

def saved_cost_filters
  @saved_cost_filters
end

#schedulesSchedulesNamespace (readonly)

Returns client.schedules.

Returns:



15307
15308
15309
# File 'lib/infrawrench/client.rb', line 15307

def schedules
  @schedules
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



15309
15310
15311
# File 'lib/infrawrench/client.rb', line 15309

def search
  @search
end

#session_recordingsSessionRecordingsNamespace (readonly)

Returns client.session_recordings.

Returns:



15311
15312
15313
# File 'lib/infrawrench/client.rb', line 15311

def session_recordings
  @session_recordings
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



15313
15314
15315
# File 'lib/infrawrench/client.rb', line 15313

def sftp
  @sftp
end

#shared_consolesSharedConsolesNamespace (readonly)

Returns client.shared_consoles.

Returns:



15315
15316
15317
# File 'lib/infrawrench/client.rb', line 15315

def shared_consoles
  @shared_consoles
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



15317
15318
15319
# File 'lib/infrawrench/client.rb', line 15317

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



15319
15320
15321
# File 'lib/infrawrench/client.rb', line 15319

def sql
  @sql
end

#ssh_fanoutSshFanoutNamespace (readonly)

Returns client.ssh_fanout.

Returns:



15321
15322
15323
# File 'lib/infrawrench/client.rb', line 15321

def ssh_fanout
  @ssh_fanout
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



15323
15324
15325
# File 'lib/infrawrench/client.rb', line 15323

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



15325
15326
15327
# File 'lib/infrawrench/client.rb', line 15325

def ssh_tunnels
  @ssh_tunnels
end

#statusStatusNamespace (readonly)

Returns client.status.

Returns:



15327
15328
15329
# File 'lib/infrawrench/client.rb', line 15327

def status
  @status
end

#status_incidentsStatusIncidentsNamespace (readonly)

Returns client.status_incidents.

Returns:



15329
15330
15331
# File 'lib/infrawrench/client.rb', line 15329

def status_incidents
  @status_incidents
end

#status_pagesStatusPagesNamespace (readonly)

Returns client.status_pages.

Returns:



15331
15332
15333
# File 'lib/infrawrench/client.rb', line 15331

def status_pages
  @status_pages
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



15333
15334
15335
# File 'lib/infrawrench/client.rb', line 15333

def storage
  @storage
end

#tag_policyTagPolicyNamespace (readonly)

Returns client.tag_policy.

Returns:



15335
15336
15337
# File 'lib/infrawrench/client.rb', line 15335

def tag_policy
  @tag_policy
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



15337
15338
15339
# File 'lib/infrawrench/client.rb', line 15337

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



15165
15166
15167
# File 'lib/infrawrench/client.rb', line 15165

def transport
  @transport
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



15339
15340
15341
# File 'lib/infrawrench/client.rb', line 15339

def workflow_approvals
  @workflow_approvals
end

#workflow_secretsWorkflowSecretsNamespace (readonly)

Returns client.workflow_secrets.

Returns:



15341
15342
15343
# File 'lib/infrawrench/client.rb', line 15341

def workflow_secrets
  @workflow_secrets
end

#workflowsWorkflowsNamespace (readonly)

Returns client.workflows.

Returns:



15343
15344
15345
# File 'lib/infrawrench/client.rb', line 15343

def workflows
  @workflows
end