Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.accounts

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
5770
5771
5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
5782
5783
5784
5785
5786
5787
# File 'lib/infrawrench/client.rb', line 5749

def initialize(**options)
  @transport = Transport.new(**options)
  @accounts = AccountsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
end

Instance Attribute Details

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



5674
5675
5676
# File 'lib/infrawrench/client.rb', line 5674

def accounts
  @accounts
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



5676
5677
5678
# File 'lib/infrawrench/client.rb', line 5676

def agents
  @agents
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



5678
5679
5680
# File 'lib/infrawrench/client.rb', line 5678

def api_keys
  @api_keys
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



5680
5681
5682
# File 'lib/infrawrench/client.rb', line 5680

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



5682
5683
5684
# File 'lib/infrawrench/client.rb', line 5682

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



5684
5685
5686
# File 'lib/infrawrench/client.rb', line 5684

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



5686
5687
5688
# File 'lib/infrawrench/client.rb', line 5686

def auth
  @auth
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



5688
5689
5690
# File 'lib/infrawrench/client.rb', line 5688

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



5690
5691
5692
# File 'lib/infrawrench/client.rb', line 5690

def billing
  @billing
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



5692
5693
5694
# File 'lib/infrawrench/client.rb', line 5692

def budgets
  @budgets
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



5694
5695
5696
# File 'lib/infrawrench/client.rb', line 5694

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



5696
5697
5698
# File 'lib/infrawrench/client.rb', line 5696

def changes
  @changes
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



5698
5699
5700
# File 'lib/infrawrench/client.rb', line 5698

def connect
  @connect
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



5700
5701
5702
# File 'lib/infrawrench/client.rb', line 5700

def costs
  @costs
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



5702
5703
5704
# File 'lib/infrawrench/client.rb', line 5702

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



5704
5705
5706
# File 'lib/infrawrench/client.rb', line 5704

def dashboards
  @dashboards
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



5706
5707
5708
# File 'lib/infrawrench/client.rb', line 5706

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



5708
5709
5710
# File 'lib/infrawrench/client.rb', line 5708

def digest
  @digest
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



5710
5711
5712
# File 'lib/infrawrench/client.rb', line 5710

def docker
  @docker
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



5712
5713
5714
# File 'lib/infrawrench/client.rb', line 5712

def invitations
  @invitations
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



5714
5715
5716
# File 'lib/infrawrench/client.rb', line 5714

def kv
  @kv
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



5716
5717
5718
# File 'lib/infrawrench/client.rb', line 5716

def msteams
  @msteams
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



5718
5719
5720
# File 'lib/infrawrench/client.rb', line 5718

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



5720
5721
5722
# File 'lib/infrawrench/client.rb', line 5720

def orphans
  @orphans
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



5722
5723
5724
# File 'lib/infrawrench/client.rb', line 5722

def pages
  @pages
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



5724
5725
5726
# File 'lib/infrawrench/client.rb', line 5724

def profile
  @profile
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



5726
5727
5728
# File 'lib/infrawrench/client.rb', line 5726

def resources
  @resources
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



5728
5729
5730
# File 'lib/infrawrench/client.rb', line 5728

def search
  @search
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



5730
5731
5732
# File 'lib/infrawrench/client.rb', line 5730

def sftp
  @sftp
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



5732
5733
5734
# File 'lib/infrawrench/client.rb', line 5732

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



5734
5735
5736
# File 'lib/infrawrench/client.rb', line 5734

def sql
  @sql
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



5736
5737
5738
# File 'lib/infrawrench/client.rb', line 5736

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



5738
5739
5740
# File 'lib/infrawrench/client.rb', line 5738

def ssh_tunnels
  @ssh_tunnels
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



5740
5741
5742
# File 'lib/infrawrench/client.rb', line 5740

def storage
  @storage
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



5742
5743
5744
# File 'lib/infrawrench/client.rb', line 5742

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



5672
5673
5674
# File 'lib/infrawrench/client.rb', line 5672

def transport
  @transport
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



5744
5745
5746
# File 'lib/infrawrench/client.rb', line 5744

def workflow_approvals
  @workflow_approvals
end