Class: Infrawrench::APIV1Client

Inherits:
Object
  • Object
show all
Defined in:
lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs

Overview

A client for the Infrawrench API.

client = Infrawrench::APIV1Client.new(
  api_key: ENV.fetch("INFRAWRENCH_API_KEY"),
  org_id: ENV.fetch("INFRAWRENCH_ORG_ID")
)
client.accounts

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**options) ⇒ APIV1Client

Returns a new instance of APIV1Client.

Parameters:

  • options (Hash)

    Client configuration — :base_url, :api_key, :org_id, :headers, :timeout, :open_timeout and :http_handler. See Transport#initialize, which owns the list.

  • (Object)


5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
5745
5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
# File 'lib/infrawrench/client.rb', line 5722

def initialize(**options)
  @transport = Transport.new(**options)
  @accounts = AccountsNamespace.new(@transport)
  @agents = AgentsNamespace.new(@transport)
  @api_keys = ApiKeysNamespace.new(@transport)
  @artifacts = ArtifactsNamespace.new(@transport)
  @associations = AssociationsNamespace.new(@transport)
  @audit_logs = AuditLogsNamespace.new(@transport)
  @auth = AuthNamespace.new(@transport)
  @bastions = BastionsNamespace.new(@transport)
  @billing = BillingNamespace.new(@transport)
  @budgets = BudgetsNamespace.new(@transport)
  @change_freezes = ChangeFreezesNamespace.new(@transport)
  @changes = ChangesNamespace.new(@transport)
  @connect = ConnectNamespace.new(@transport)
  @costs = CostsNamespace.new(@transport)
  @custom_graphs = CustomGraphsNamespace.new(@transport)
  @dashboards = DashboardsNamespace.new(@transport)
  @deployments = DeploymentsNamespace.new(@transport)
  @digest = DigestNamespace.new(@transport)
  @docker = DockerNamespace.new(@transport)
  @invitations = InvitationsNamespace.new(@transport)
  @kv = KvNamespace.new(@transport)
  @msteams = MsteamsNamespace.new(@transport)
  @orgs = OrgsNamespace.new(@transport)
  @orphans = OrphansNamespace.new(@transport)
  @pages = PagesNamespace.new(@transport)
  @profile = ProfileNamespace.new(@transport)
  @resources = ResourcesNamespace.new(@transport)
  @search = SearchNamespace.new(@transport)
  @sftp = SftpNamespace.new(@transport)
  @slack = SlackNamespace.new(@transport)
  @sql = SqlNamespace.new(@transport)
  @ssh_keys = SshKeysNamespace.new(@transport)
  @ssh_tunnels = SshTunnelsNamespace.new(@transport)
  @storage = StorageNamespace.new(@transport)
  @team = TeamNamespace.new(@transport)
  @workflow_approvals = WorkflowApprovalsNamespace.new(@transport)
end

Instance Attribute Details

#accountsAccountsNamespace (readonly)

Returns client.accounts.

Returns:



5647
5648
5649
# File 'lib/infrawrench/client.rb', line 5647

def accounts
  @accounts
end

#agentsAgentsNamespace (readonly)

Returns client.agents.

Returns:



5649
5650
5651
# File 'lib/infrawrench/client.rb', line 5649

def agents
  @agents
end

#api_keysApiKeysNamespace (readonly)

Returns client.api_keys.

Returns:



5651
5652
5653
# File 'lib/infrawrench/client.rb', line 5651

def api_keys
  @api_keys
end

#artifactsArtifactsNamespace (readonly)

Returns client.artifacts.

Returns:



5653
5654
5655
# File 'lib/infrawrench/client.rb', line 5653

def artifacts
  @artifacts
end

#associationsAssociationsNamespace (readonly)

Returns client.associations.

Returns:



5655
5656
5657
# File 'lib/infrawrench/client.rb', line 5655

def associations
  @associations
end

#audit_logsAuditLogsNamespace (readonly)

Returns client.audit_logs.

Returns:



5657
5658
5659
# File 'lib/infrawrench/client.rb', line 5657

def audit_logs
  @audit_logs
end

#authAuthNamespace (readonly)

Returns client.auth.

Returns:



5659
5660
5661
# File 'lib/infrawrench/client.rb', line 5659

def auth
  @auth
end

#bastionsBastionsNamespace (readonly)

Returns client.bastions.

Returns:



5661
5662
5663
# File 'lib/infrawrench/client.rb', line 5661

def bastions
  @bastions
end

#billingBillingNamespace (readonly)

Returns client.billing.

Returns:



5663
5664
5665
# File 'lib/infrawrench/client.rb', line 5663

def billing
  @billing
end

#budgetsBudgetsNamespace (readonly)

Returns client.budgets.

Returns:



5665
5666
5667
# File 'lib/infrawrench/client.rb', line 5665

def budgets
  @budgets
end

#change_freezesChangeFreezesNamespace (readonly)

Returns client.change_freezes.

Returns:



5667
5668
5669
# File 'lib/infrawrench/client.rb', line 5667

def change_freezes
  @change_freezes
end

#changesChangesNamespace (readonly)

Returns client.changes.

Returns:



5669
5670
5671
# File 'lib/infrawrench/client.rb', line 5669

def changes
  @changes
end

#connectConnectNamespace (readonly)

Returns client.connect.

Returns:



5671
5672
5673
# File 'lib/infrawrench/client.rb', line 5671

def connect
  @connect
end

#costsCostsNamespace (readonly)

Returns client.costs.

Returns:



5673
5674
5675
# File 'lib/infrawrench/client.rb', line 5673

def costs
  @costs
end

#custom_graphsCustomGraphsNamespace (readonly)

Returns client.custom_graphs.

Returns:



5675
5676
5677
# File 'lib/infrawrench/client.rb', line 5675

def custom_graphs
  @custom_graphs
end

#dashboardsDashboardsNamespace (readonly)

Returns client.dashboards.

Returns:



5677
5678
5679
# File 'lib/infrawrench/client.rb', line 5677

def dashboards
  @dashboards
end

#deploymentsDeploymentsNamespace (readonly)

Returns client.deployments.

Returns:



5679
5680
5681
# File 'lib/infrawrench/client.rb', line 5679

def deployments
  @deployments
end

#digestDigestNamespace (readonly)

Returns client.digest.

Returns:



5681
5682
5683
# File 'lib/infrawrench/client.rb', line 5681

def digest
  @digest
end

#dockerDockerNamespace (readonly)

Returns client.docker.

Returns:



5683
5684
5685
# File 'lib/infrawrench/client.rb', line 5683

def docker
  @docker
end

#invitationsInvitationsNamespace (readonly)

Returns client.invitations.

Returns:



5685
5686
5687
# File 'lib/infrawrench/client.rb', line 5685

def invitations
  @invitations
end

#kvKvNamespace (readonly)

Returns client.kv.

Returns:



5687
5688
5689
# File 'lib/infrawrench/client.rb', line 5687

def kv
  @kv
end

#msteamsMsteamsNamespace (readonly)

Returns client.msteams.

Returns:



5689
5690
5691
# File 'lib/infrawrench/client.rb', line 5689

def msteams
  @msteams
end

#orgsOrgsNamespace (readonly)

Returns client.orgs.

Returns:



5691
5692
5693
# File 'lib/infrawrench/client.rb', line 5691

def orgs
  @orgs
end

#orphansOrphansNamespace (readonly)

Returns client.orphans.

Returns:



5693
5694
5695
# File 'lib/infrawrench/client.rb', line 5693

def orphans
  @orphans
end

#pagesPagesNamespace (readonly)

Returns client.pages.

Returns:



5695
5696
5697
# File 'lib/infrawrench/client.rb', line 5695

def pages
  @pages
end

#profileProfileNamespace (readonly)

Returns client.profile.

Returns:



5697
5698
5699
# File 'lib/infrawrench/client.rb', line 5697

def profile
  @profile
end

#resourcesResourcesNamespace (readonly)

Returns client.resources.

Returns:



5699
5700
5701
# File 'lib/infrawrench/client.rb', line 5699

def resources
  @resources
end

#searchSearchNamespace (readonly)

Returns client.search.

Returns:



5701
5702
5703
# File 'lib/infrawrench/client.rb', line 5701

def search
  @search
end

#sftpSftpNamespace (readonly)

Returns client.sftp.

Returns:



5703
5704
5705
# File 'lib/infrawrench/client.rb', line 5703

def sftp
  @sftp
end

#slackSlackNamespace (readonly)

Returns client.slack.

Returns:



5705
5706
5707
# File 'lib/infrawrench/client.rb', line 5705

def slack
  @slack
end

#sqlSqlNamespace (readonly)

Returns client.sql.

Returns:



5707
5708
5709
# File 'lib/infrawrench/client.rb', line 5707

def sql
  @sql
end

#ssh_keysSshKeysNamespace (readonly)

Returns client.ssh_keys.

Returns:



5709
5710
5711
# File 'lib/infrawrench/client.rb', line 5709

def ssh_keys
  @ssh_keys
end

#ssh_tunnelsSshTunnelsNamespace (readonly)

Returns client.ssh_tunnels.

Returns:



5711
5712
5713
# File 'lib/infrawrench/client.rb', line 5711

def ssh_tunnels
  @ssh_tunnels
end

#storageStorageNamespace (readonly)

Returns client.storage.

Returns:



5713
5714
5715
# File 'lib/infrawrench/client.rb', line 5713

def storage
  @storage
end

#teamTeamNamespace (readonly)

Returns client.team.

Returns:



5715
5716
5717
# File 'lib/infrawrench/client.rb', line 5715

def team
  @team
end

#transportTransport (readonly)

Returns Shared request plumbing. Reach for this only to inspect the resolved base URL.

Returns:

  • (Transport)

    Shared request plumbing. Reach for this only to inspect the resolved base URL.



5645
5646
5647
# File 'lib/infrawrench/client.rb', line 5645

def transport
  @transport
end

#workflow_approvalsWorkflowApprovalsNamespace (readonly)

Returns client.workflow_approvals.

Returns:



5717
5718
5719
# File 'lib/infrawrench/client.rb', line 5717

def workflow_approvals
  @workflow_approvals
end