Class: Infrawrench::ChatConversationsSecretRequestsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ChatConversationsSecretRequestsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.chat.conversations.secret_requests
Instance Method Summary collapse
-
#create(conversation_id:, request_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Submit a requested workflow secret.
-
#initialize(transport) ⇒ ChatConversationsSecretRequestsNamespace
constructor
private
A new instance of ChatConversationsSecretRequestsNamespace.
Constructor Details
#initialize(transport) ⇒ ChatConversationsSecretRequestsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ChatConversationsSecretRequestsNamespace.
3018 3019 3020 |
# File 'lib/infrawrench/client.rb', line 3018 def initialize(transport) @transport = transport end |
Instance Method Details
#create(conversation_id:, request_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Submit a requested workflow secret
Human-only, write-only handoff from the chat password field to encrypted workflow-secret storage. The value is never returned or added to chat history.
POST /api/org/orgId/chat/conversations/conversationId/secret-requests/requestId
Raises on 400: Bad request
Raises on 403: Forbidden
Raises on 404: Not found
Raises on 409: Conflict
3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 |
# File 'lib/infrawrench/client.rb', line 3048 def create(conversation_id:, request_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/chat/conversations/{conversationId}/secret-requests/{requestId}", path_params: { "orgId" => org_id, "conversationId" => conversation_id, "requestId" => request_id }, body: body, request_options: ) end |