Class: Infrawrench::ConnectNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ConnectNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.connect
Instance Method Summary collapse
-
#env_deploy(body:, org_id: nil, request_options: nil) ⇒ Hash
Deploy env vars from a source resource to an SSH target.
-
#initialize(transport) ⇒ ConnectNamespace
constructor
private
A new instance of ConnectNamespace.
-
#secret_export(body:, org_id: nil, request_options: nil) ⇒ Hash
Materialize source outputs as a secret in the target (e.g. K8s).
-
#templates(body:, org_id: nil, request_options: nil) ⇒ Hash
List secret-export templates and target capabilities.
Constructor Details
#initialize(transport) ⇒ ConnectNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ConnectNamespace.
1549 1550 1551 |
# File 'lib/infrawrench/client.rb', line 1549 def initialize(transport) @transport = transport end |
Instance Method Details
#env_deploy(body:, org_id: nil, request_options: nil) ⇒ Hash
Deploy env vars from a source resource to an SSH target
Requires permission: resources:execute.
POST /api/org/orgId/connect/env-deploy
Raises on 400: Bad request
Raises on 404: Not found
1569 1570 1571 1572 1573 1574 1575 1576 1577 |
# File 'lib/infrawrench/client.rb', line 1569 def env_deploy(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/connect/env-deploy", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#secret_export(body:, org_id: nil, request_options: nil) ⇒ Hash
Materialize source outputs as a secret in the target (e.g. K8s)
Requires permission: resources:write.
POST /api/org/orgId/connect/secret-export
Raises on 400: Bad request
Raises on 404: Not found
1595 1596 1597 1598 1599 1600 1601 1602 1603 |
# File 'lib/infrawrench/client.rb', line 1595 def secret_export(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/connect/secret-export", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#templates(body:, org_id: nil, request_options: nil) ⇒ Hash
List secret-export templates and target capabilities
Requires permission: resources:read.
POST /api/org/orgId/connect/templates
Raises on 404: Not found
1620 1621 1622 1623 1624 1625 1626 1627 1628 |
# File 'lib/infrawrench/client.rb', line 1620 def templates(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/connect/templates", path_params: { "orgId" => org_id }, body: body, request_options: ) end |