Class: Infrawrench::DependencyGraphNamespace
- Inherits:
-
Object
- Object
- Infrawrench::DependencyGraphNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.dependency_graph
Instance Method Summary collapse
-
#get(org_id: nil, resource_id: nil, request_options: nil) ⇒ Hash
The org's resource dependency graph, from synced cloud data and output references.
-
#initialize(transport) ⇒ DependencyGraphNamespace
constructor
private
A new instance of DependencyGraphNamespace.
Constructor Details
#initialize(transport) ⇒ DependencyGraphNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of DependencyGraphNamespace.
2745 2746 2747 |
# File 'lib/infrawrench/client.rb', line 2745 def initialize(transport) @transport = transport end |
Instance Method Details
#get(org_id: nil, resource_id: nil, request_options: nil) ⇒ Hash
The org's resource dependency graph, from synced cloud data and output references
Requires permission: resources:read.
GET /api/org/orgId/dependency-graph
2763 2764 2765 2766 2767 2768 2769 2770 2771 |
# File 'lib/infrawrench/client.rb', line 2763 def get(org_id: nil, resource_id: nil, request_options: nil) @transport.request( http_method: "GET", path: "/api/org/{orgId}/dependency-graph", path_params: { "orgId" => org_id }, query: { "resourceId" => resource_id }, request_options: ) end |