Class: Infrawrench::IncidentsGetNamespace
- Inherits:
-
Object
- Object
- Infrawrench::IncidentsGetNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.incidents.get
Instance Method Summary collapse
-
#get(org_id: nil, status: nil, request_options: nil) ⇒ Hash
List declared incidents.
-
#get_org_org_id_incidents_incident_id(incident_id:, org_id: nil, request_options: nil) ⇒ Hash
Read one incident.
-
#initialize(transport) ⇒ IncidentsGetNamespace
constructor
private
A new instance of IncidentsGetNamespace.
Constructor Details
#initialize(transport) ⇒ IncidentsGetNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of IncidentsGetNamespace.
7640 7641 7642 |
# File 'lib/infrawrench/client.rb', line 7640 def initialize(transport) @transport = transport end |
Instance Method Details
#get(org_id: nil, status: nil, request_options: nil) ⇒ Hash
List declared incidents
Every incident the organization has declared, newest first, each with the artefacts its declaration created — including the ones that failed.
Requires permission: incidents:read.
GET /api/org/orgId/incidents
7659 7660 7661 7662 7663 7664 7665 7666 7667 |
# File 'lib/infrawrench/client.rb', line 7659 def get(org_id: nil, status: nil, request_options: nil) @transport.request( http_method: "GET", path: "/api/org/{orgId}/incidents", path_params: { "orgId" => org_id }, query: { "status" => status }, request_options: ) end |
#get_org_org_id_incidents_incident_id(incident_id:, org_id: nil, request_options: nil) ⇒ Hash
Read one incident
The incident with its artefacts and its operator notes.
Requires permission: incidents:read.
GET /api/org/orgId/incidents/incidentId
Raises on 404: Not found
7685 7686 7687 7688 7689 7690 7691 7692 |
# File 'lib/infrawrench/client.rb', line 7685 def get_org_org_id_incidents_incident_id(incident_id:, org_id: nil, request_options: nil) @transport.request( http_method: "GET", path: "/api/org/{orgId}/incidents/{incidentId}", path_params: { "orgId" => org_id, "incidentId" => incident_id }, request_options: ) end |