Class: Infrawrench::ResourcesSecretVersionsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ResourcesSecretVersionsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.resources.secret_versions
Instance Method Summary collapse
-
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time).
-
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version.
-
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource.
-
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
constructor
private
A new instance of ResourcesSecretVersionsNamespace.
-
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version.
Constructor Details
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ResourcesSecretVersionsNamespace.
5407 5408 5409 |
# File 'lib/infrawrench/client.rb', line 5407 def initialize(transport) @transport = transport end |
Instance Method Details
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time)
Requires permission: secrets:read.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/access
Raises on 400: Bad request
Raises on 404: Not found
5430 5431 5432 5433 5434 5435 5436 5437 5438 |
# File 'lib/infrawrench/client.rb', line 5430 def access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/access", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/add
Raises on 400: Bad request
Raises on 404: Not found
5459 5460 5461 5462 5463 5464 5465 5466 5467 |
# File 'lib/infrawrench/client.rb', line 5459 def add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/add", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource
Requires permission: secrets:read.
GET /api/org/orgId/resources/pluginId/typeId/secret-versions
Raises on 400: Bad request
Raises on 404: Not found
5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 |
# File 'lib/infrawrench/client.rb', line 5490 def get( plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil ) @transport.request( http_method: "GET", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, query: { "resourceId" => resource_id, "accountId" => account_id, "parentResourceId" => parent_resource_id }, request_options: ) end |
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/modify
Raises on 400: Bad request
Raises on 404: Not found
Raises on 423: Blocked by an active change freeze. Retry with the
x-change-freeze-override: true header if you hold freezes:override;
both blocks and overrides are audit-logged.
5535 5536 5537 5538 5539 5540 5541 5542 5543 |
# File 'lib/infrawrench/client.rb', line 5535 def modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/modify", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |