Class: Infrawrench::ResourcesSecretVersionsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ResourcesSecretVersionsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.resources.secret_versions
Instance Method Summary collapse
-
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time).
-
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version.
-
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource.
-
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
constructor
private
A new instance of ResourcesSecretVersionsNamespace.
-
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version.
Constructor Details
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ResourcesSecretVersionsNamespace.
3308 3309 3310 |
# File 'lib/infrawrench/client.rb', line 3308 def initialize(transport) @transport = transport end |
Instance Method Details
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time)
Requires permission: secrets:read.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/access
Raises on 400: Bad request
Raises on 404: Not found
3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/infrawrench/client.rb', line 3331 def access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/access", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/add
Raises on 400: Bad request
Raises on 404: Not found
3360 3361 3362 3363 3364 3365 3366 3367 3368 |
# File 'lib/infrawrench/client.rb', line 3360 def add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/add", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource
Requires permission: secrets:read.
GET /api/org/orgId/resources/pluginId/typeId/secret-versions
Raises on 400: Bad request
Raises on 404: Not found
3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/infrawrench/client.rb', line 3391 def get( plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil ) @transport.request( http_method: "GET", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, query: { "resourceId" => resource_id, "accountId" => account_id, "parentResourceId" => parent_resource_id }, request_options: ) end |
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/modify
Raises on 400: Bad request
Raises on 404: Not found
3432 3433 3434 3435 3436 3437 3438 3439 3440 |
# File 'lib/infrawrench/client.rb', line 3432 def modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/modify", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |