Class: Infrawrench::ResourcesSecretVersionsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ResourcesSecretVersionsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.resources.secret_versions
Instance Method Summary collapse
-
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time).
-
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version.
-
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource.
-
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
constructor
private
A new instance of ResourcesSecretVersionsNamespace.
-
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version.
Constructor Details
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ResourcesSecretVersionsNamespace.
2633 2634 2635 |
# File 'lib/infrawrench/client.rb', line 2633 def initialize(transport) @transport = transport end |
Instance Method Details
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time)
Requires permission: secrets:read.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/access
Raises on 400: Bad request
Raises on 404: Not found
2656 2657 2658 2659 2660 2661 2662 2663 2664 |
# File 'lib/infrawrench/client.rb', line 2656 def access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/access", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/add
Raises on 400: Bad request
Raises on 404: Not found
2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/infrawrench/client.rb', line 2685 def add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/add", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource
Requires permission: secrets:read.
GET /api/org/orgId/resources/pluginId/typeId/secret-versions
Raises on 400: Bad request
Raises on 404: Not found
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 |
# File 'lib/infrawrench/client.rb', line 2716 def get( plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil ) @transport.request( http_method: "GET", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, query: { "resourceId" => resource_id, "accountId" => account_id, "parentResourceId" => parent_resource_id }, request_options: ) end |
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/modify
Raises on 400: Bad request
Raises on 404: Not found
2757 2758 2759 2760 2761 2762 2763 2764 2765 |
# File 'lib/infrawrench/client.rb', line 2757 def modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/modify", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |