Class: Infrawrench::ResourcesSecretVersionsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::ResourcesSecretVersionsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.resources.secret_versions
Instance Method Summary collapse
-
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time).
-
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version.
-
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource.
-
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
constructor
private
A new instance of ResourcesSecretVersionsNamespace.
-
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version.
Constructor Details
#initialize(transport) ⇒ ResourcesSecretVersionsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ResourcesSecretVersionsNamespace.
2509 2510 2511 |
# File 'lib/infrawrench/client.rb', line 2509 def initialize(transport) @transport = transport end |
Instance Method Details
#access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Reveal the plaintext value of a specific version (one-time)
Requires permission: secrets:read.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/access
Raises on 400: Bad request
Raises on 404: Not found
2532 2533 2534 2535 2536 2537 2538 2539 2540 |
# File 'lib/infrawrench/client.rb', line 2532 def access(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/access", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Add a new secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/add
Raises on 400: Bad request
Raises on 404: Not found
2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/infrawrench/client.rb', line 2561 def add(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/add", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |
#get(plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil) ⇒ Hash
List secret versions for a versioned-secret resource
Requires permission: secrets:read.
GET /api/org/orgId/resources/pluginId/typeId/secret-versions
Raises on 400: Bad request
Raises on 404: Not found
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 |
# File 'lib/infrawrench/client.rb', line 2592 def get( plugin_id:, type_id:, resource_id:, account_id:, org_id: nil, parent_resource_id: nil, request_options: nil ) @transport.request( http_method: "GET", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, query: { "resourceId" => resource_id, "accountId" => account_id, "parentResourceId" => parent_resource_id }, request_options: ) end |
#modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) ⇒ Hash
Enable/disable/destroy a secret version
Requires permission: secrets:write.
POST /api/org/orgId/resources/pluginId/typeId/secret-versions/modify
Raises on 400: Bad request
Raises on 404: Not found
2633 2634 2635 2636 2637 2638 2639 2640 2641 |
# File 'lib/infrawrench/client.rb', line 2633 def modify(plugin_id:, type_id:, body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/resources/{pluginId}/{typeId}/secret-versions/modify", path_params: { "orgId" => org_id, "pluginId" => plugin_id, "typeId" => type_id }, body: body, request_options: ) end |