Class: Infrawrench::SshTunnelsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::SshTunnelsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.ssh_tunnels
Instance Method Summary collapse
-
#active(org_id: nil, request_options: nil) ⇒ Hash
List active tunnels for this org.
-
#close(body:, org_id: nil, request_options: nil) ⇒ Hash
Close a tunnel by id.
-
#create_account(body:, org_id: nil, request_options: nil) ⇒ Hash
Create an account whose traffic is tunneled over SSH.
-
#exec(body:, org_id: nil, request_options: nil) ⇒ Hash
Run a command over SSH using an org SSH key.
-
#initialize(transport) ⇒ SshTunnelsNamespace
constructor
private
A new instance of SshTunnelsNamespace.
-
#open(body:, org_id: nil, request_options: nil) ⇒ Hash
Re-open the tunnel for an existing account.
Constructor Details
#initialize(transport) ⇒ SshTunnelsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SshTunnelsNamespace.
5910 5911 5912 |
# File 'lib/infrawrench/client.rb', line 5910 def initialize(transport) @transport = transport end |
Instance Method Details
#active(org_id: nil, request_options: nil) ⇒ Hash
List active tunnels for this org
Requires permission: resources:execute.
GET /api/org/orgId/ssh-tunnels/active
5925 5926 5927 5928 5929 5930 5931 5932 |
# File 'lib/infrawrench/client.rb', line 5925 def active(org_id: nil, request_options: nil) @transport.request( http_method: "GET", path: "/api/org/{orgId}/ssh-tunnels/active", path_params: { "orgId" => org_id }, request_options: ) end |
#close(body:, org_id: nil, request_options: nil) ⇒ Hash
Close a tunnel by id
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/close
5946 5947 5948 5949 5950 5951 5952 5953 5954 |
# File 'lib/infrawrench/client.rb', line 5946 def close(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/close", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#create_account(body:, org_id: nil, request_options: nil) ⇒ Hash
Create an account whose traffic is tunneled over SSH
Verifies the SSH connection works before persisting.
Requires permission: accounts:write.
POST /api/org/orgId/ssh-tunnels/create-account
Raises on 400: Bad request
Raises on 404: Not found
5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/infrawrench/client.rb', line 5975 def create_account(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/create-account", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#exec(body:, org_id: nil, request_options: nil) ⇒ Hash
Run a command over SSH using an org SSH key
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/exec
Raises on 400: Bad request
Raises on 404: Not found
6001 6002 6003 6004 6005 6006 6007 6008 6009 |
# File 'lib/infrawrench/client.rb', line 6001 def exec(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/exec", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#open(body:, org_id: nil, request_options: nil) ⇒ Hash
Re-open the tunnel for an existing account
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/open
Raises on 404: Not found
6025 6026 6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/infrawrench/client.rb', line 6025 def open(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/open", path_params: { "orgId" => org_id }, body: body, request_options: ) end |