Class: Infrawrench::SshTunnelsNamespace
- Inherits:
-
Object
- Object
- Infrawrench::SshTunnelsNamespace
- Defined in:
- lib/infrawrench/client.rb,
sig/infrawrench/sdk.rbs
Overview
client.ssh_tunnels
Instance Method Summary collapse
-
#active(org_id: nil, request_options: nil) ⇒ Hash
List active tunnels for this org.
-
#close(body:, org_id: nil, request_options: nil) ⇒ Hash
Close a tunnel by id.
-
#create_account(body:, org_id: nil, request_options: nil) ⇒ Hash
Create an account whose traffic is tunneled over SSH.
-
#exec(body:, org_id: nil, request_options: nil) ⇒ Hash
Run a command over SSH using an org SSH key.
-
#initialize(transport) ⇒ SshTunnelsNamespace
constructor
private
A new instance of SshTunnelsNamespace.
-
#open(body:, org_id: nil, request_options: nil) ⇒ Hash
Re-open the tunnel for an existing account.
Constructor Details
#initialize(transport) ⇒ SshTunnelsNamespace
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of SshTunnelsNamespace.
4677 4678 4679 |
# File 'lib/infrawrench/client.rb', line 4677 def initialize(transport) @transport = transport end |
Instance Method Details
#active(org_id: nil, request_options: nil) ⇒ Hash
List active tunnels for this org
Requires permission: resources:execute.
GET /api/org/orgId/ssh-tunnels/active
4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/infrawrench/client.rb', line 4692 def active(org_id: nil, request_options: nil) @transport.request( http_method: "GET", path: "/api/org/{orgId}/ssh-tunnels/active", path_params: { "orgId" => org_id }, request_options: ) end |
#close(body:, org_id: nil, request_options: nil) ⇒ Hash
Close a tunnel by id
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/close
4713 4714 4715 4716 4717 4718 4719 4720 4721 |
# File 'lib/infrawrench/client.rb', line 4713 def close(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/close", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#create_account(body:, org_id: nil, request_options: nil) ⇒ Hash
Create an account whose traffic is tunneled over SSH
Verifies the SSH connection works before persisting.
Requires permission: accounts:write.
POST /api/org/orgId/ssh-tunnels/create-account
Raises on 400: Bad request
Raises on 404: Not found
4742 4743 4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/infrawrench/client.rb', line 4742 def create_account(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/create-account", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#exec(body:, org_id: nil, request_options: nil) ⇒ Hash
Run a command over SSH using an org SSH key
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/exec
Raises on 400: Bad request
Raises on 404: Not found
4768 4769 4770 4771 4772 4773 4774 4775 4776 |
# File 'lib/infrawrench/client.rb', line 4768 def exec(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/exec", path_params: { "orgId" => org_id }, body: body, request_options: ) end |
#open(body:, org_id: nil, request_options: nil) ⇒ Hash
Re-open the tunnel for an existing account
Requires permission: resources:execute.
POST /api/org/orgId/ssh-tunnels/open
Raises on 404: Not found
4792 4793 4794 4795 4796 4797 4798 4799 4800 |
# File 'lib/infrawrench/client.rb', line 4792 def open(body:, org_id: nil, request_options: nil) @transport.request( http_method: "POST", path: "/api/org/{orgId}/ssh-tunnels/open", path_params: { "orgId" => org_id }, body: body, request_options: ) end |